set more off
capture mkdir $zambia_results/graph_components

************
* Define Function!
************

capture program drop coef_plotter
program define coef_plotter
	args public_good_var public_good_name axis subgraph
	set more off
	use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear

	gen ln_network_pop = log(network_pop_2)


	if "`subgraph'"=="cut3"{
		local subgraph_title = "All-Days, > 2"
	}
	if "`subgraph'"=="cut7"{
		local subgraph_title = "All-Days, > 6"
	}
	if "`subgraph'"=="wd3"{
		local subgraph_title = "Weekend-Only, > 2"

	}
	if "`subgraph'"=="wd7"{
		local subgraph_title = "Weekend-Only, > 6"
	}


	* temporary file
	*---------------
	tempname memhold
	tempfile results
	postfile `memhold' beta se resolution using `results'


	* Max rez parameter
	*------------------
	sum max_sig_resolution_`subgraph'
	local max_sig_res = ln(`r(mean)')

	* regression
	*-----------
	gen ln_area = log(area_sqkm)
	label var ln_area "Log Area"

	local rezlist "60600000 36800000 22400000 13600000 08200000 05000000 03000000 01800000 01110000 00680000 00408000 00240000 00150400 00092000 00055400 00034000 00020340 00012400 00007480 00004600 00002760 00001600 00001014 00000600 00000372 00000200 00000138 00000050"
	foreach rez in `rezlist'{


		sum frac_`subgraph'_0_`rez',d
		local sd = `r(sd)'
		display "Standard deviation is stored as: `sd'"



			local controls  "ln_area ln_census_pop rural mmd_01 mmd_06 flag_copperbelt flag_lusaka ln_network_pop"
			areg `public_good_var' frac_`subgraph'_0_`rez' `controls', cluster(provName) a(provName)

		post `memhold' (_b[frac_`subgraph'_0_`rez'] / `sd') (  _se[frac_`subgraph'_0_`rez'] / `sd') (0.`rez')
	}

	* post the data
	*--------------

	postclose `memhold'
	use `results', clear

	* confidence intervals
	*---------------------

	gen cihi = beta + 1.66*se
	gen cilo = beta - 1.66*se
	gen ln_rez = log(resolution)
	gen tstat = float(round(abs(beta/se), 0.0001))


	sum tstat, d
	sum resolution if float(tstat) == float(round(`r(max)',0.0001))
	local max_t_res = `r(mean)'
	local ln_max_t_res = log(`max_t_res')


	global max_res_`subgraph' = `max_t_res'


	* plots
	*-----

	foreach cutoff in 8 7 6 4 2 0 {
	preserve

		keep if ln_rez > -15 & ln_rez < -`cutoff'

	#delimit;

	twoway
		( rcap cihi cilo ln_rez if cilo>0 | cihi <0, color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
		( scatter beta ln_rez if cilo>0 | cihi <0, color(red) msymbol(diamond) msize(small)
			xline(`max_sig_res', lpattern(dash) lcolor(red))
			xline(`ln_max_t_res', lpattern(solid) lcolor(blue)) )
		( rcap cihi cilo ln_rez if cilo<0 & cihi>0,  color(black) lwidth(medthick))
		( scatter beta ln_rez if cilo <0 & cihi>0,
			xline(`max_sig_res', lpattern(dash) lcolor(red))
			xline(`ln_max_t_res', lpattern(solid) lcolor(blue))
			color(black) msymbol(diamond) msize(small))
			, ylabel( ,nogrid angle(hori) labsize(small))
			xscale(`axis' range(-15 0))
			xtitle("Logged Resolution Parameter")
			yscale(noline )
			graphregion(fcolor(white) lcolor(white))
			plotregion(fcolor(white) lstyle(none) lcolor(white) ilstyle(none) )
			ytitle("Network Fragmentation &" "Public Goods Partial Corr",
				angle(hori)	color(black) size(small) margin(0) bmargin(0))
			legend( off )
			title("`subgraph_title'")
		;

	#delimit cr


	graph export $zambia_results/pgood_`subgraph'_`cutoff'.pdf, replace
	graph save $zambia_results/graph_components/g_`subgraph'_`cutoff'.gph, replace
	restore
	}




end



		coef_plotter dev_pca_weighted  "cut3" off "cut3"
		coef_plotter dev_pca_weighted  "cut7" off "cut7"
		coef_plotter dev_pca_weighted  "wd3" on "wd3"
		coef_plotter dev_pca_weighted  "wd7" on "wd7"


		cd $zambia_results/graph_components/
		#delimit ;
		foreach cutoff in 8 7 6 4 2 0 {;

			graph combine
				g_cut3_`cutoff'.gph
				g_cut7_`cutoff'.gph
				g_wd3_`cutoff'.gph
				g_wd7_`cutoff'.gph
			,
			xcommon col(2)   ///
			graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and Public Goods") subtitle("By Resolution Parameter and Filter");
			graph export $zambia_results/pgoods_combined_bygraph_`cutoff'_p90.pdf, replace;
		;;
		};


	#delimit cr

set more off
set trace on
clear
set obs 5
gen subgraph=""
gen res = .
local i=1
foreach x in "cut3" "cut7" "wd3" "wd7" {
	replace subgraph="`x'" if _n==`i'
	local i = `i'+1
}


replace res=$max_res_cut3 if subgraph=="cut3"
replace res=$max_res_cut7 if subgraph=="cut7"
replace res=$max_res_wd3 if subgraph=="wd3"
replace res=$max_res_wd7 if subgraph=="wd7"


save $zambia/intermediate_data/100_aggregated_network_and_demographics/public_good_max_sig.dta, replace
