



set more off


************
* Define Function!
************

capture program drop coef_plotter
program define coef_plotter
	args afro_var afro_name axis subgraph
	set more off
	use $zambia/intermediate_data/110_afrobarometer/afro_and_network.dta, replace
		*keep if urban_share < 0.3

	gen ln_network_pop = log(network_pop_2)


	if "`subgraph'"=="cut3"{
		local subgraph_title = "All-Days, > 2"
	}
	if "`subgraph'"=="cut7"{
		local subgraph_title = "All-Days, > 6"
	}
	if "`subgraph'"=="wd3"{
		local subgraph_title = "Weekend-Only, > 2"

	}
	if "`subgraph'"=="wd7"{
		local subgraph_title = "Weekend-Only, > 6"
	}


	* temporary file
	*---------------
	tempname memhold
	tempfile results
	postfile `memhold' beta se resolution using `results'


	* Max rez parameter
	*------------------
	sum max_sig_resolution_`subgraph'
	local max_sig_res = ln(`r(mean)')

	* regression
	*-----------
	gen ln_area = log(area_sqkm)
	label var ln_area "Log Area"

	local rezlist "60600000 36800000 22400000 13600000 08200000 05000000 03000000 01800000 01110000 00680000 00408000 00240000 00150400 00092000 00055400 00034000 00020340 00012400 00007480 00004600 00002760 00001600 00001014 00000600 00000372 00000200 00000138 00000050"
	foreach rez in `rezlist'{


		sum frac_`subgraph'_0_`rez',d
		local sd = `r(sd)'
		display "Standard deviation is stored as: `sd'"



			local const_controls  "ln_area ln_census_pop rural flag_copperbelt flag_lusaka ln_network_pop"
			local afro_controls "basic_female basic_pcaWealthIndex basic_urban basic_educPrimaryComplete"
			areg `afro_var' frac_`subgraph'_0_`rez' `const_controls' `afro_controls', cluster(site_num) a(provName)

			post `memhold' (_b[frac_`subgraph'_0_`rez'] / _se[frac_`subgraph'_0_`rez']) ( 1) (0.`rez')
	}

	* post the data
	*--------------

	postclose `memhold'
	use `results', clear

	* confidence intervals
	*---------------------

	gen cihi = beta + 1.66*se
	gen cilo = beta - 1.66*se
	gen ln_rez = log(resolution)
	keep if ln_rez > -15

	gen tstat = round(abs(beta/se), 0.0001)


	sum tstat, d
	sum resolution if float(tstat) == float(round(`r(max)',0.0001))
	local max_t_res = `r(mean)'
	local ln_max_t_res = log(`max_t_res')


	global afro_max_res_`subgraph' = `max_t_res'


	* plot
	*-----

	#delimit;


	twoway
		( rcap cihi cilo ln_rez if (cilo>0 | cihi <0), color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
					( rcap cihi cilo ln_rez if (cilo>0 | cihi <0), color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
		( scatter beta ln_rez if cilo>0 | cihi <0, color(red) msymbol(diamond) msize(small)
			xline(`max_sig_res', lpattern(dash) lcolor(red))
			xline(`ln_max_t_res', lpattern(solid) lcolor(blue)) )
		( rcap cihi cilo ln_rez if cilo<0 & cihi>0,  color(black) lwidth(medthick))
		( scatter beta ln_rez if cilo <0 & cihi>0,
			xline(`max_sig_res', lpattern(dash) lcolor(red))
			xline(`ln_max_t_res', lpattern(solid) lcolor(blue))
			color(black) msymbol(diamond) msize(small))
			, ylabel( ,nogrid angle(hori) labsize(small))
			xscale(`axis' range(-15 0))
			xtitle("Logged Resolution Parameter")
			yscale(noline )
			graphregion(fcolor(white) lcolor(white))
			plotregion(fcolor(white) lstyle(none) lcolor(white) ilstyle(none) )
			ytitle("Network Fragmentation &" "Political Knowledge",
				angle(hori)	color(black) size(small) margin(0) bmargin(0))
			legend( off )
			title("`subgraph_title'")
		;
	#delimit cr


	graph save $zambia_results/graph_components/afro_`subgraph'_se.gph, replace

end
foreach knowledge_var in mp_allQuestions {


		coef_plotter PolKnowIndex_`knowledge_var'  "cut3" off "cut3"
		coef_plotter PolKnowIndex_`knowledge_var'  "cut7" off "cut7"
		coef_plotter PolKnowIndex_`knowledge_var'  "wd3" on "wd3"
		coef_plotter PolKnowIndex_`knowledge_var'  "wd7" on "wd7"


		cd $zambia_results/graph_components/
	#delimit ;
		graph combine
			afro_cut3_se.gph
			afro_cut7_se.gph
			afro_wd3_se.gph
			afro_wd7_se.gph
			,
			xcommon col(2)   ///
			graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and Political Knowledge") subtitle("By Resolution Parameter and Filter");
		graph export $zambia_results/afro_know_combined_bygraph_`knowledge_var'_se_p90.pdf, replace;

		use $zambia/intermediate_data/110_afrobarometer/afro_and_network.dta, clear;

	#delimit cr
}
