# -*- coding: utf-8 -*-
"""
Created on Fri Sep 18 20:33:15 2015

@author: Nick
"""

##
import pandas as pd
import numpy as np
import os
import sys

pd.options.display.max_rows = 200
pd.options.display.max_columns = 90
pd.set_option('display.width', 150)
pd.set_option('io.hdf.default_format', 'table')
pd.set_option('mode.chained_assignment','raise')

##
wd = r'/Volumes/Zambia/'
os.chdir(wd)


import seaborn as sns
sns.set(color_codes=True)
import matplotlib.pyplot as plt



###################
# Gather Substantive
####################


# Get the substantively selected resolutions
cols = dict([('cut3','comm_0.00055400'), ('cut7','comm_0.00055400'), ('wd3','comm_0.00020340'),('wd7','comm_0.00000200')])

# Check still correspond to updated values
values = pd.read_stata('intermediate_data/100_aggregated_network_and_demographics/mean_significance_values.dta')[['subgraph','mean']]
values = values.set_index('subgraph')
import re
for i in cols.keys():
    hand_answer = np.log(float(re.sub('comm_','',cols[i])))
    print(hand_answer)
    print(values.loc[i])
    assert np.isclose(a = hand_answer,b = values.loc[i], rtol=0.012)


# Communities
comm_vect = dict()

names = {'cut3':'All-Days, >2', 'cut7':'All-Days, >6', 'wd3':'Weekend-Only, >2', 'wd7':'Weekend-Only, >6'}

for graph in ['cut3', 'cut7', 'wd3', 'wd7']:

    target_res = cols[graph]
    comms = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', graph)
    comms = comms[['userCode',target_res]]
    comms[names[graph]] = comms.groupby([target_res]).transform(len)
    comm_vect[graph] = comms[names[graph]]

#####
# Summary STats
#####
from tabulate import tabulate

comm_stats = pd.DataFrame({'mean':[0]*4, 'median':[0]*4, 'max':[0]*4},
                           index=['All-Days, >2', 'All-Days, >6', 'Weekend-Only, >2', 'Weekend-Only, >6'])

comm_stats = comm_stats[['mean','median','max']]
for graph in ['cut3', 'cut7', 'wd3', 'wd7']:
    comm_stats.loc[names[graph],'mean'] = comm_vect[graph].mean()
    comm_stats.loc[names[graph],'median'] = comm_vect[graph].median()
    comm_stats.loc[names[graph],'max'] = comm_vect[graph].max()



################
# Now get results from Significance optimizing to combine
##################

# Guide to most sig resolutions
max_values = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/max_values')



# Communities
comm_vect = dict()

names = {'cut3':'All-Days, >2', 'cut7':'All-Days, >6', 'wd3':'Weekend-Only, >2', 'wd7':'Weekend-Only, >6'}

for graph in ['cut3', 'cut7', 'wd3', 'wd7']:

    target_res = round(np.exp(max_values.loc[graph]['max_res']), 8)
    target_res = 'comm_{:0.8f}'.format(target_res)

    comms = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', graph)
    comms = comms[['userCode',target_res]]
    comms[names[graph]] = comms.groupby([target_res]).transform(len)
    comm_vect[graph] = comms[names[graph]]

#####
# Summary STats
#####
from tabulate import tabulate

sig_comm_stats = pd.DataFrame({'mean':[0]*4, 'median':[0]*4, 'max':[0]*4},
                           index=['All-Days, >2', 'All-Days, >6', 'Weekend-Only, >2', 'Weekend-Only, >6'])

for graph in ['cut3', 'cut7', 'wd3', 'wd7']:
    sig_comm_stats.loc[names[graph],'mean'] = comm_vect[graph].mean()
    sig_comm_stats.loc[names[graph],'median'] = comm_vect[graph].median()
    sig_comm_stats.loc[names[graph],'max'] = comm_vect[graph].max()

# Order random before this because dicts don't preserve order!
sig_comm_stats = sig_comm_stats[['mean', 'median', 'max']]


##################
# Merge and table
###################

sig_comm_stats[['mean_new', 'median_new', 'max_new']] = comm_stats[['mean', 'median', 'max']]
headers = ['Atheoretic Mean', 'Atheoretic Median', 'Atheoretic Max',
           'Theory Mean', 'Theory Median', 'Theory Max']
table = tabulate(sig_comm_stats, headers, tablefmt="latex_booktabs", floatfmt=",.0f")
table

with open("results/community_summary_stats_substantive.tex", "w") as outfile:
    outfile.writelines(table)
