
set more off
set trace off


* get pgood resolutions
use $zambia/intermediate_data/100_aggregated_network_and_demographics/mean_significance_values.dta, clear
foreach i in "cut3" "cut7" "wd3" "wd7"{
	sum mean if subgraph=="`i'"
	global pgood_res_`i' = `r(max)'
}
display $pgood_res_cut7


************
* Define Function!
************

capture program drop coef_plotter_const
program define coef_plotter_const
	args elf subgraph axis rural_restriction
	set more off
	use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear
		if (`rural_restriction' >= 0){
			keep if rural >= `rural_restriction'
		}
		else {
			keep if rural < -(`rural_restriction')
		}

	if "`subgraph'"=="cut3"{
		local subgraph_title = "All-Days, > 2"
		local pgood_res = $pgood_res_cut3
	}
	if "`subgraph'"=="cut7"{
		local subgraph_title = "All-Days, > 6"
		local pgood_res = $pgood_res_cut7
}
	if "`subgraph'"=="wd3"{
		local subgraph_title = "Weekend-Only, > 2"
		local pgood_res = $pgood_res_wd3

	}
	if "`subgraph'"=="wd7"{
		local subgraph_title = "Weekend-Only, > 6"
	local pgood_res = $pgood_res_wd7
	}


	* temporary file
	*---------------
	tempname memhold
	tempfile results
	postfile `memhold' beta se resolution using `results'


	* Max rez parameter
	*------------------
	sum max_sig_resolution_`subgraph'
	local max_sig_res = log(`r(mean)')

	* regression
	*-----------
	gen ln_area = log(area_sqkm)
	label var ln_area "Log Area"

	local rezlist "60600000 36800000 22400000 13600000 08200000 05000000 03000000 01800000 01110000 00680000 00408000 00240000 00150400 00092000 00055400 00034000 00020340 00012400 00007480 00004600 00002760 00001600 00001014 00000600 00000372 00000200 00000138 00000050"
	foreach rez in `rezlist'{

		sum frac_`subgraph'_0_`rez',d
		local sd = `r(sd)'
		display "Standard deviation is stored as: `sd'"

			local controls  "ln_area ln_census_pop rural ln_net_pop flag_lusaka flag_copperbelt"
			areg frac_`subgraph'_0_`rez' `elf' `controls', cluster(provName) a(provName)

			post `memhold' (_b[`elf']/`sd') (_se[`elf']/`sd' ) (0.`rez')

	}

	* post the data
	*--------------

	postclose `memhold'
	use `results', clear

	* confidence intervals
	*---------------------

	gen cihi = beta + 1.66*se
	gen cilo = beta - 1.66*se
	gen ln_rez = log(resolution)
	keep if ln_rez > -15


	* plot
	*-----

	#delimit;


	* With Sig;
	twoway
		( rcap cihi cilo ln_rez if cilo>0 | cihi <0, color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
		( scatter beta ln_rez if cilo>0 | cihi <0, color(red) msymbol(diamond) msize(small)
			xline(`pgood_res', lpattern(solid) lcolor(blue)) )
		( rcap cihi cilo ln_rez if cilo<0 & cihi>0,  color(black) lwidth(medthick))
		( scatter beta ln_rez if cilo <0 & cihi>0,
			xline(`pgood_res', lpattern(solid) lcolor(blue))
			color(black) msymbol(diamond) msize(small))
			, ylabel( ,nogrid angle(hori) labsize(small))
			xscale(`axis' range(-15 0))
			xtitle("Logged Resolution Parameter")
			yscale(noline )
			graphregion(fcolor(white) lcolor(white))
			plotregion(fcolor(white) lstyle(none) lcolor(white) ilstyle(none) )
			ytitle("Network Fragmentation &" "ELF",
				angle(hori)	color(black) size(small) margin(0) bmargin(0))
			legend( off )
			title("`subgraph_title'")
		;;

	graph export $zambia_results/elf_`subgraph'.pdf, replace;
	graph save $zambia_results/graph_components/`elf'_const_`subgraph'.gph, replace;

	twoway
		( rcap cihi cilo ln_rez if cilo>0 | cihi <0, color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
		( scatter beta ln_rez if cilo>0 | cihi <0, color(red) msymbol(diamond) msize(small))
		( rcap cihi cilo ln_rez if cilo<0 & cihi>0,  color(black) lwidth(medthick))
		( scatter beta ln_rez if cilo <0 & cihi>0,
			color(black) msymbol(diamond) msize(small))
			, ylabel( ,nogrid angle(hori) labsize(small))
			xscale(`axis' range(-15 0))
			xtitle("Logged Resolution Parameter")
			yscale(noline )
			graphregion(fcolor(white) lcolor(white))
			plotregion(fcolor(white) lstyle(none) lcolor(white) ilstyle(none) )
			ytitle("Network Fragmentation &" "ELF",
				angle(hori)	color(black) size(small) margin(0) bmargin(0))
			legend( off )
			title("`subgraph_title'")
		;
	graph export $zambia_results/elf_`subgraph'_nosig.pdf, replace;
	graph save $zambia_results/graph_components/`elf'_const_`subgraph'_nosig.gph, replace;

	#delimit cr


	end


	**************
	* Primary full sample regression
	**************


	coef_plotter_const "ELF_big5"  "cut3" off 0
	coef_plotter_const "ELF_big5"  "cut7" off 0
	coef_plotter_const "ELF_big5"  "wd3" on 0
	coef_plotter_const "ELF_big5"  "wd7" on 0



		cd $zambia_results/graph_components/
	#delimit ;
	graph combine
		ELF_big5_const_cut3.gph
		ELF_big5_const_cut7.gph
		ELF_big5_const_wd3.gph
		ELF_big5_const_wd7.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and ELF") ///
		subtitle("Constituency-Level, By Resolution Parameter and Filter");
	graph export $zambia_results/const_ELF_big5_p90.pdf, replace;


	;;
	#delimit ;

		graph combine
		ELF_big5_const_cut3_nosig.gph
		ELF_big5_const_cut7_nosig.gph
		ELF_big5_const_wd3_nosig.gph
		ELF_big5_const_wd7_nosig.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and ELF") ///
		subtitle("Constituency-Level, By Resolution Parameter and Filter");
	graph export $zambia_results/const_ELF_big5_nosig_p90.pdf, replace;


		;;


	#delimit cr



************
* Rural Only
************

		coef_plotter_const "ELF_big5"  "cut3" off 0.7
		coef_plotter_const "ELF_big5"  "cut7" off 0.7
		coef_plotter_const "ELF_big5"  "wd3" on 0.7
		coef_plotter_const "ELF_big5"  "wd7" on 0.7
			use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear

			count if rural > 0.7
			local counter = `r(N)'

		cd $zambia_results/graph_components/
	#delimit ;
	graph combine
		ELF_big5_const_cut3_nosig.gph
		ELF_big5_const_cut7_nosig.gph
		ELF_big5_const_wd3_nosig.gph
		ELF_big5_const_wd7_nosig.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Rural Network Fractionalization and ELF") subtitle("Population At Least 70% Rural")
		note( "Includes `counter' Constituencies with >70% rural populations.");
	graph export $zambia_results/const_ELF_big5_rural_7_p90.pdf, replace;

		;;


	#delimit cr




		coef_plotter_const "ELF_big5"  "cut3" off 0.85
		coef_plotter_const "ELF_big5"  "cut7" off 0.85
		coef_plotter_const "ELF_big5"  "wd3" on 0.85
		coef_plotter_const "ELF_big5"  "wd7" on 0.85

			use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear

			count if rural > 0.85
			local counter = `r(N)'

		cd $zambia_results/graph_components/
	#delimit ;
	graph combine
		ELF_big5_const_cut3_nosig.gph
		ELF_big5_const_cut7_nosig.gph
		ELF_big5_const_wd3_nosig.gph
		ELF_big5_const_wd7_nosig.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Rural Network Fragmentation and ELF") subtitle("Population At Least 85% Rural")
		note("Includes `counter' Constituencies with >85% rural populations.");
	graph export $zambia_results/const_ELF_big5_rural_85_p90.pdf, replace;

		;;


	#delimit cr


	************
	* Urban sample
	************



	#delimit cr


		coef_plotter_const "ELF_big5"  "cut3" off -0.3
		coef_plotter_const "ELF_big5"  "cut7" off -0.3
		coef_plotter_const "ELF_big5"  "wd3" on -0.3
		coef_plotter_const "ELF_big5"  "wd7" on  -0.3

			use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear

			count if rural < 0.3
			local counter = `r(N)'

		cd $zambia_results/graph_components/
	#delimit ;
	graph combine
		ELF_big5_const_cut3_nosig.gph
		ELF_big5_const_cut7_nosig.gph
		ELF_big5_const_wd3_nosig.gph
		ELF_big5_const_wd7_nosig.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Rural Network Fragmentation and ELF") subtitle("Population At Least 85% Rural")
		note("Includes `counter' Constituencies with >70% urban populations.");
	graph export $zambia_results/const_ELF_big5_urban_70_p90.pdf, replace;

		;;


	#delimit cr






	*************
	* # Full sample limited controls
	*************

capture program drop coef_plotter_const_nofe
program define coef_plotter_const_nofe
	args elf subgraph axis rural_restriction
	set more off
	use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear
		keep if rural >= `rural_restriction'

	if "`subgraph'"=="cut3"{
		local subgraph_title = "All-Days, > 2"
		local pgood_res = $pgood_res_cut3
	}
	if "`subgraph'"=="cut7"{
		local subgraph_title = "All-Days, > 6"
		local pgood_res = $pgood_res_cut7
}
	if "`subgraph'"=="wd3"{
		local subgraph_title = "Weekend-Only, > 2"
		local pgood_res = $pgood_res_wd3

	}
	if "`subgraph'"=="wd7"{
		local subgraph_title = "Weekend-Only, > 6"
	local pgood_res = $pgood_res_wd7
	}


	* temporary file
	*---------------
	tempname memhold
	tempfile results
	postfile `memhold' beta se resolution using `results'


	* Max rez parameter
	*------------------
	sum max_sig_resolution_`subgraph'
	local max_sig_res = log(`r(mean)')

	* regression
	*-----------
	gen ln_area = log(area_sqkm)
	label var ln_area "Log Area"

	local rezlist "60600000 36800000 22400000 13600000 08200000 05000000 03000000 01800000 01110000 00680000 00408000 00240000 00150400 00092000 00055400 00034000 00020340 00012400 00007480 00004600 00002760 00001600 00001014 00000600 00000372 00000200 00000138 00000050"
	foreach rez in `rezlist'{

		sum frac_`subgraph'_0_`rez',d
		local sd = `r(sd)'
		display "Standard deviation is stored as: `sd'"
			local controls  "ln_area ln_census_pop rural ln_net_pop flag_lusaka flag_copperbelt"

			reg frac_`subgraph'_0_`rez' `elf' `controls'

			post `memhold' (_b[`elf']/`sd') (_se[`elf']/`sd' ) (0.`rez')

	}

	* post the data
	*--------------

	postclose `memhold'
	use `results', clear

	* confidence intervals
	*---------------------

	gen cihi = beta + 1.96*se
	gen cilo = beta - 1.96*se
	gen ln_rez = log(resolution)
	keep if ln_rez > -15


	* plot
	*-----

	#delimit;


	twoway
		( rcap cihi cilo ln_rez if cilo>0 | cihi <0, color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
		( scatter beta ln_rez if cilo>0 | cihi <0, color(red) msymbol(diamond) msize(small))
		( rcap cihi cilo ln_rez if cilo<0 & cihi>0,  color(black) lwidth(medthick))
		( scatter beta ln_rez if cilo <0 & cihi>0,
			color(black) msymbol(diamond) msize(small))
			, ylabel( ,nogrid angle(hori) labsize(small))
			xscale(`axis' range(-15 0))
			xtitle("Logged Resolution Parameter")
			yscale(noline )
			graphregion(fcolor(white) lcolor(white))
			plotregion(fcolor(white) lstyle(none) lcolor(white) ilstyle(none) )
			ytitle("Network Fractionalization &" "ELF",
				angle(hori)	color(black) size(small) margin(0) bmargin(0))
			legend( off )
			title("`subgraph_title'")
		;
	graph export $zambia_results/elf_`subgraph'_nosig_nofe_p90.pdf, replace;
	graph save $zambia_results/graph_components/`elf'_const_`subgraph'_nosig_nofe.gph, replace;

	#delimit cr


	end


	coef_plotter_const_nofe "ELF_big5"  "cut3" off 0
	coef_plotter_const_nofe "ELF_big5"  "cut7" off 0
	coef_plotter_const_nofe "ELF_big5"  "wd3" on 0
	coef_plotter_const_nofe "ELF_big5"  "wd7" on 0



		cd $zambia_results/graph_components/
	#delimit ;

		graph combine
		ELF_big5_const_cut3_nosig_nofe.gph
		ELF_big5_const_cut7_nosig_nofe.gph
		ELF_big5_const_wd3_nosig_nofe.gph
		ELF_big5_const_wd7_nosig_nofe.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and ELF") ///
		subtitle("No Province Fixed Effects");
	graph export $zambia_results/const_ELF_big5_nosig_nofe_p90.pdf, replace;


		;;


	#delimit cr



	coef_plotter_const_nofe "ELF_big5"  "cut3" off 0.7
	coef_plotter_const_nofe "ELF_big5"  "cut7" off 0.7
	coef_plotter_const_nofe "ELF_big5"  "wd3" on 0.7
	coef_plotter_const_nofe "ELF_big5"  "wd7" on 0.7



		cd $zambia_results/graph_components/
	#delimit ;

		graph combine
		ELF_big5_const_cut3_nosig_nofe.gph
		ELF_big5_const_cut7_nosig_nofe.gph
		ELF_big5_const_wd3_nosig_nofe.gph
		ELF_big5_const_wd7_nosig_nofe.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and ELF") ///
		subtitle("70% Rural, No Province Fixed Effects");
	graph export $zambia_results/const_ELF_big5_rural_nosig_nofe_p90.pdf, replace;


		;;


	#delimit cr
