
set more off

* get pgood resolutions
use $zambia/intermediate_data/100_aggregated_network_and_demographics/mean_significance_values.dta, clear
foreach i in "cut3" "cut7" "wd3" "wd7"{
	sum mean if subgraph=="`i'"
	global sub_res_`i' = `r(max)'
	global sub_res_`i'_exptd = exp(`r(max)')
	display exp(`r(max)')

}
display $sub_res_cut7


use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear
gen ln_area = log(area_sqkm)


***********
* Make var for frac at most sig levels
***********

foreach i in "cut3" "cut7" "wd3" "wd7" {
	sum max_sig_resolution_`i'
	local max_`i': display %8.7f `r(mean)'
	display "`max_`i''"
	local max_`i' = subinstr("`max_`i''", ".", "_", .)
	gen frac_max_sig_resolution_`i' = frac_`i'_`max_`i''0

	}


* These won't replicate because based on "closest", not exact, so need to be hard-coded.
local num = 0

if(round($sub_res_cut3_exptd,0.000001) == 0.000554){
	gen frac_max_sub_resolution_cut3 = frac_cut3_0_00055400
	local num = `num' + 1
	display "cut3 ok"
	}
if(round($sub_res_cut7_exptd, 0.00000001) == 0.00055929){
	gen frac_max_sub_resolution_cut7 = frac_cut7_0_00055400
	local num = `num' + 1
	display "cut7 ok"
	}
if(round($sub_res_wd3_exptd,0.00000001) == 0.00020357){
	gen frac_max_sub_resolution_wd3 = frac_wd3_0_00020340
	local num = `num' + 1
	display "wd3 ok"

	}
if(round($sub_res_wd7_exptd,0.000000001) == 0.000001732){
	gen frac_max_sub_resolution_wd7 = frac_wd7_0_0000020
	local num = `num' + 1
	display "wd7 ok"
	}
assert `num'==4

gen ln_network_pop = log(network_pop_2)


* Rural Limited
set more off
foreach type in "sig" "sub" {
	foreach filter in "cut3" "cut7" "wd3" "wd7" {


		if"`filter'"=="cut3"{
			local subgraph_title = "All-Days, > 2"
		}
		if "`filter'"=="cut7"{
			local subgraph_title = "All-Days, > 6"
		}
		if "`filter'"=="wd3"{
			local subgraph_title = "Weekend-Only, > 2"
		}
		if "`filter'"=="wd7"{
			local subgraph_title = "Weekend-Only, > 6"
		}



		* Complex
		preserve
			keep if rural > 0.7
			count
			local count = `r(N)'

		capture drop resids*

		local controls "ln_network_pop ln_census_pop ln_area rural flag_lusaka flag_copperbelt i.provName"


		xi:reg frac_max_`type'_resolution_`filter'  `controls'
		predict resids_network, resid

		xi:reg ELF_big5  `controls'
		predict resids_elf, resid

		reg resids_network resids_elf, cluster(provName)
		local sig = round(_b[resids_elf]/_se[resids_elf], 0.01)
		local sig : di %5.2f `sig'
		display `sig'
		local pvalue =  round(2*ttail(e(df_r),abs(`sig')),0.001)
		local pvalue : di %5.3f `pvalue'
		display `pvalue'

		display `pvalue'

		twoway ///
			(lfitci resids_network resids_elf) ///
			(scatter resids_network resids_elf, msymbol(O) mcolor(black)  ) ///
			, ///
		title("`subgraph_title'") ytitle("Network Fragmentation") ///
		graphregion( color(white) ) ///
		xtitle("ELF") legend(off) note("T-Statistic: `sig', P-Value `pvalue'")

		tempfile `filter'_rural
		graph save ``filter'_rural'.gph, replace
		restore
	}

	if "`type'"=="sub"{
		local title = "Constituency ELF and Network Fragmentation "
		local subtitle = "Substantively-Chosen Resolution Parameter"
	}
	else{
		local title = "Constituency ELF and Network Frag"
		local subtitle = "Significance-Optimizing Resolution Parameter"
	}
		graph combine `cut3_rural'.gph `cut7_rural'.gph `wd3_rural'.gph `wd7_rural'.gph , ///
		title("`subtitle'")  ///
		graphregion( color(white) ) plotregion(color(white)) ///
		note("95% Confidence Intervals Plotted" "Standard Errors clustered at Province level" "Includes `count' Constituencies at least 70% rural populations")

	graph export $zambia_results/full_controls_`type'_rural.pdf, replace
}
