# -*- coding: utf-8 -*-
"""
Created on Mon Mar  7 18:27:16 2016

@author: Nick
"""
import pandas as pd
import numpy as np
import os
import re
##


os.chdir('/volumes/zambia/')

df = pd.read_stata('third_party_data/cell_usage/research_ict/ria12.dta').query('zambia==1')
assert len(df) == 881


# Filter down
df = df.filter(regex='(m\_.*|EA.*|w\_.*|i\_.*)')


############
# Clean up
############
renames = {'EA_3':'sample_group',
           'm_1re':'has_mobile',
           'm_3':'num_sims',
           'm_7':'carrier',
           'i_6':'language',
           'm_39':'call_most',
           'm_38':'called_by_most'}


df = df.rename(columns=renames)
df = df.filter(items=renames.values())


df.language = df.language.str.lower()
language_groups = {'tumbuka':'nyanja',
                   'mambwe':'bemba',
                   'nsenga':'nyanja',
                   'chewa':'nyanja',
                   'ngoni':'nyanja',
                   'mbunda':'nw',
                   'luvale':'nw',
                   'lunda':'nw',
                   'kaonde':'nw',
                   'namwanga':'bemba',
                   'luchazi':'nw',
                   'nyanja/bemba':'nyanja',
                   'bisa':'bemba',
                   'ngonl':'nyanja',
                   'nsengq':'nyanja',
                   'bemba/nyanja/english':'bemba',
                   'senga':'nyanja',
                   'nsenga/chewa':'nyanja',
                   'nyanjja':'nyanja',
                   'lala':'bemba',
                   'nyanja and english':'nyanja',
                   'nyanja and bemba':'nyanja',
                   'nyanja, lenje, bemba':'nyanja',
                   'shona':'drop',
                    'ndebele':'drop',
                    'lenje':'tonga',
                    'chichewa':'nyanja',
                    'ila':'tonga',
                    'english':'drop',
                    'lamba':'bemba',
                    'lingala':'drop',
                    'soli':'tonga',
                    ' lingala':'drop',
                    'tonga and english':'tonga',
                    'nyanya':'nyanja',
                    'bemba and nyanja':'bemba',
                    'swahili':'drop',
                    'lozi/english':'lozi',
                    'chewa and ngoni':'nyanja',
                    'nyika':'drop',
                    'nyama':'drop',
                    ' ':'drop',
                    'chokwe':'nw',
                    'lunda/chewa':'nw'}

df.language = df.language.replace(to_replace=language_groups)

df.language.value_counts()

df.carrier = df.carrier.str.lower()

carrier_fixes = {'celz':'zamtel', 'cellz':'zamtel', 'cell z':'zamtel',
                 ' celtel':'celtel', 'ceitel':'celtel', 'celte':'celtel',
                  'cel tel':'celtel', 'celtek':'celtel', 'celtei':'celtel',
                  'celtel/mtn':'celtel', 'celtel mtn cell z':'celtel',
                  'celtel, mtn':'celtel', 'celtel and cell z':'celtel',
                  'celltel':'celtel', 'cellz & celtel':'zamtel', '/=':np.nan,
                  'celtel and mtn':'celtel', ' ':np.nan, '':np.nan, '  ':np.nan}

df.carrier = df.carrier.replace(to_replace=carrier_fixes)
carriers = {'celtel':'CelTel','mtn':'MTN','zamtel':'ZamTel'}
df.carrier = df.carrier.replace(carriers)

df.carrier.value_counts()



######
# Analyses
######

# Linguistic group / carrier distribution

w_mobile = df[df.has_mobile.astype('bool')]
w_mobile = w_mobile[~(w_mobile.language=='drop') & pd.notnull(w_mobile.carrier)]
w_mobile.language = w_mobile.language.str.capitalize()
w_mobile.language = w_mobile.language.replace({'Nw':"NW"})

l = list()
for i in w_mobile.carrier.unique():
    temp = w_mobile.query('carrier=="{}"'.format(i)).language.value_counts(normalize=True)
    temp.name = i
    l.append(temp)

ctab = pd.concat(l, axis=1)
ctab = ctab[['CelTel', 'ZamTel', 'MTN']]

sizes = w_mobile.groupby('carrier').size()

sizes.name="No. Obs."
ctab = ctab.append(sizes)
ctab = ctab.fillna(0)

ctab = ctab.applymap(lambda x:'{:2.1f}%'.format(x*100))
ctab = ctab.applymap(lambda x:re.sub('25600.0%','256',x))
ctab = ctab.applymap(lambda x:re.sub('1700.0%','17',x))
ctab = ctab.applymap(lambda x:re.sub('2800.0%','28',x))
table = ctab.to_latex()
with open("results/carrier_language.tex", "w") as outfile:
    outfile.writelines(table)


# Num sim cards
share_with_1_sim = df.num_sims.value_counts().loc[1] / len(df[pd.notnull(df.num_sims)])
share = '{:.1f}'.format(share_with_1_sim*100)
share
    # 94\% have 1.
with open("results/share_one_sim.tex", "w") as outfile:
    outfile.writelines(share)


# Call most:
thinned = df[(df.has_mobile==1) & pd.notnull(df.call_most)].copy()
thinned.call_most = thinned.call_most.str.capitalize()
series = thinned.call_most.value_counts(normalize=True)
table_most = pd.DataFrame(series)
table_most.columns=['Share of Respondents']
table_most = table_most.to_latex(float_format=lambda x: '{:.1%}'.format(x))
print(table_most)
with open("results/most_called.tex", "w") as outfile:
    outfile.writelines(table_most)


# Share frequently?

#######
# Summary!
#######

# Ethnic / language

#######
# Sampling:
# 14 Rural
# 16 Major Urban (Lusaka / Livingston / Ndola)
# 12 Other Urban
#
# All households listed, then sampled from list.
#
# One person per household selected at random from age 16 or older
######



# EA_3: Type of EA
# HHHwomen: -- household head woman?
# Mobile phone questions "m_"


# own mobile: m_1 / m_1re
# Language of home: i_6
# Num active sim cards: m_3
# If more than one, how often change: m_3b

# m_5: Use cases
# m_7: Service provider ("main" if multiple)
# m_8: Why did you pick?
# m_25: Do others use your phone regularly?

# Who dyou call most: m_38
# Who calls you most: m_39
# main purpose of last 10 calls you received: m_40
# Main purpose of last 10 calls you made: m_41
