
set more off
set trace off


* get pgood resolutions
use $zambia/intermediate_data/100_aggregated_network_and_demographics/mean_significance_values.dta, clear
foreach i in "cut3" "cut7" "wd3" "wd7"{
	sum mean if subgraph=="`i'"
	global pgood_res_`i' = `r(max)'
}
display $pgood_res_cut7


************
* Define Function!
************

capture program drop coef_plotter_const
program define coef_plotter_const
	args placebo subgraph axis
	set more off
	use $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_const.dta, clear

	if "`subgraph'"=="cut3"{
		local subgraph_title = "All-Days, > 2"
	}
	if "`subgraph'"=="cut7"{
		local subgraph_title = "All-Days, > 6"
}
	if "`subgraph'"=="wd3"{
		local subgraph_title = "Weekend-Only, > 2"

	}
	if "`subgraph'"=="wd7"{
		local subgraph_title = "Weekend-Only,  > 6"
	}


	* temporary file
	*---------------
	tempname memhold
	tempfile results
	postfile `memhold' beta se resolution using `results'


	* Max rez parameter
	*------------------
	sum max_sig_resolution_`subgraph'
	local max_sig_res = log(`r(mean)')

	* regression
	*-----------
	gen ln_area = log(area_sqkm)
	label var ln_area "Log Area"

	local rezlist "60600000 36800000 22400000 13600000 08200000 05000000 03000000 01800000 01110000 00680000 00408000 00240000 00150400 00092000 00055400 00034000 00020340 00012400 00007480 00004600 00002760 00001600 00001014 00000600 00000372 00000200 00000138 00000050"
	foreach rez in `rezlist'{

		sum frac_`subgraph'_0_`rez',d
		local sd = `r(sd)'
		display "Standard deviation is stored as: `sd'"

			local controls  "ln_area ln_census_pop rural ln_net_pop flag_lusaka flag_copperbelt"
			areg frac_`subgraph'_0_`rez' `placebo' `controls', cluster(provName) a(provName)

			post `memhold' (_b[`placebo']/`sd') (_se[`placebo']/`sd' ) (0.`rez')

	}

	* post the data
	*--------------

	postclose `memhold'
	use `results', clear

	* confidence intervals
	*---------------------

	gen cihi = beta + 1.66*se
	gen cilo = beta - 1.66*se
	gen ln_rez = log(resolution)
	keep if ln_rez > -15

	local independent_var = proper("Religious Fractionalization")
	* plot
	*-----
	cd $zambia_results/graph_components/

	#delimit;


	twoway
		( rcap cihi cilo ln_rez if cilo>0 | cihi <0, color(red) lwidth(medthick)
			yline(0, noextend lpattern(dash) lcolor(gs8) )  )
		( scatter beta ln_rez if cilo>0 | cihi <0, color(red) msymbol(diamond) msize(small))
		( rcap cihi cilo ln_rez if cilo<0 & cihi>0,  color(black) lwidth(medthick))
		( scatter beta ln_rez if cilo <0 & cihi>0,
			color(black) msymbol(diamond) msize(small))
			, ylabel( ,nogrid angle(hori) labsize(small))
			xscale(`axis' range(-15 0))
			xtitle("Logged Resolution Parameter")
			yscale(noline )
			graphregion(fcolor(white) lcolor(white))
			plotregion(fcolor(white) lstyle(none) lcolor(white) ilstyle(none) )
			ytitle("Network Fragmentation &" "`independent_var'",
				angle(hori)	color(black) size(small) margin(0) bmargin(0))
			legend( off )
			title("`subgraph_title'")
		;
	graph export $zambia_results/`placebo'_`subgraph'.pdf, replace;
	graph save $zambia_results/graph_components/`placebo'_`subgraph'.gph, replace;

	#delimit cr


	end

	**************
	* Run for Protestant
	**************


	coef_plotter_const "relig_frac"  "cut3" off
	coef_plotter_const "relig_frac"  "cut7" off
	coef_plotter_const "relig_frac"  "wd3" on
	coef_plotter_const "relig_frac"  "wd7" on



	cd $zambia_results/graph_components/

	#delimit ;

		graph combine
		relig_frac_cut3.gph
		relig_frac_cut7.gph
		relig_frac_wd3.gph
		relig_frac_wd7.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and Religious Fractionalization") ///
		subtitle("Constituency-Level, By Resolution Parameter and Filter");
	graph export $zambia_results/placebo_relig_frac_p90.pdf, replace;

		;;


	#delimit cr


	**************
	* Run for Protestant
	**************


	coef_plotter_const "industry_frac"  "cut3" off
	coef_plotter_const "industry_frac"  "cut7" off
	coef_plotter_const "industry_frac"  "wd3" on
	coef_plotter_const "industry_frac"  "wd7" on



	cd $zambia_results/graph_components/

	#delimit ;

		graph combine
		industry_frac_cut3.gph
		industry_frac_cut7.gph
		industry_frac_wd3.gph
		industry_frac_wd7.gph
		,
		xcommon col(2)   ///
		graphregion(fcolor(white) lcolor(white) ) title("Network Fragmentation and Employment Fractionalization") ///
		subtitle("Constituency-Level, By Resolution Parameter and Filter");
	graph export $zambia_results/placebo_industry_frac_p90.pdf, replace;

		;;


	#delimit cr
