# -*- coding: utf-8 -*-
from __future__ import division, print_function
import pandas as pd
import numpy as np
import os
import sys

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################


tTypes = dict(CGI = 'str', LONGTITUDE = 'float32', LATITUDE = 'float32')
towerData = pd.read_csv('pt_data/cell/CellSites_cleanedNoQuotes.csv',
    usecols = ['CGI', 'SITEID', 'ACTIVE', 'LATITUDE', 'LONGITUDE'], dtype = tTypes)

# Active towers only
towerData = towerData.query('ACTIVE == "Y"')
towerData.drop('ACTIVE', axis = 1, inplace = True)

# Towers with SITEIDs only
towerData = towerData[towerData.SITEID.notnull()]
towerData.SITEID = towerData.SITEID.astype('int32')

# Clean CGI. Some have letters. Just drop those.
towerData.CGI.value_counts(dropna = False)
towerData.CGI = towerData.CGI.str.replace(r'.*[A-Z].*', '0')
towerData.CGI = towerData.CGI.astype('int64')
towerData = towerData.query('CGI != 0')
towerData.set_index('CGI', inplace = True, verify_integrity = True)
towerData.columns

# Some have flipped signs!
towerData.describe()

def flipNegToPos(x):
    if x < 0: return x * -1
    else: return x


def flipPosToNeg(x):
    if x > 0: return x * -1
    else: return x


towerData['LONGITUDE'] = towerData.LONGITUDE.apply(flipNegToPos)
towerData['LATITUDE'] = towerData.LATITUDE.apply(flipPosToNeg)

assert len(towerData.query('LATITUDE > -8 | LATITUDE < -18.5 | LONGITUDE < 22 | LONGITUDE > 34')) == 0

# Site 2041 and 2006 at same location
towerData.loc[towerData.SITEID == 2006, 'SITEID'] = 2041

# Save a copy
towerData.to_hdf('intermediate_data/20_georeferencing_users/towerLocations.h5', 'towers')
