# -*- coding: utf-8 -*-
from __future__ import division, print_function
import pandas as pd
import numpy as np
import arcpy as ap
import os
import sys

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################


# Delete and create geodatabase

ap.env.overwriteOutput = True
ap.env.workspace = wd


databaseName = 'georef'
Output = "Outputs/20_georeferencing_users/" +databaseName
try:
    ap.Delete_management(Output, "Workspace")
    print("Deleted Old Database")
except:
    # Output.gdb did not exist, pass
    print("Did not delete")
    pass
ap.CreateFileGDB_management(ap.env.workspace, Output, "CURRENT")
print("Created New Database")


####################
# Add new materials
####################
UTM35s = ap.SpatialReference('WGS 1984 UTM Zone 35S')
wgs84 = ap.SpatialReference('WGS 1984')

###
# Towers
###
# Original file has numeric values for non-active towers. Clean
towerData = pd.read_hdf('intermediate_data/20_georeferencing_users/towerLocations.h5', 'towers')
towerData.drop_duplicates(subset = ['SITEID', 'LATITUDE', 'LONGITUDE'], inplace = True)
towerData.columns


# Check for duplicates SITEID in terms of lat long. 2041 and 2006
assert not towerData.duplicated(subset = 'SITEID').any()
towerData.reset_index(inplace = True, drop = True)

towerTable =  'pt_data/cell/justActiveSites.csv'

towerData.to_csv(towerTable)


ap.MakeXYEventLayer_management(in_x_field="LONGITUDE", in_y_field="LATITUDE",
                               table=towerTable, out_layer="temp",
                               spatial_reference = wgs84)

ap.CopyFeatures_management("temp", "Outputs/20_georeferencing_users/georef.gdb/towerWGS84")

ap.Project_management(in_dataset = "Outputs/20_georeferencing_users/georef.gdb/towerWGS84",
                         out_dataset = "Outputs/20_georeferencing_users/georef.gdb/towers",
                         out_coor_system=UTM35s)

########
# Country shapefiles
########
gisHome = 'dropbox/Inputs/GIS/Zambia_ConstituenciesAndWards_2006to2010/'
ap.CopyFeatures_management(gisHome + "Zambia_ConstituenciesAndWards_2006to2010_UTM35S.shp", "Outputs/20_georeferencing_users/georef.gdb/wards")
ap.CopyFeatures_management(gisHome + "Zambia_Constituencies_2006to2010_UTM35S.shp", "Outputs/20_georeferencing_users/georef.gdb/consts")
ap.CopyFeatures_management(gisHome + "Zambia_Country_2006to2010_UTM35S.shp", "Outputs/20_georeferencing_users/georef.gdb/country")
