# -*- coding: utf-8 -*-
from __future__ import division, print_function
import pandas as pd
import numpy as np
import arcpy as ap
import os
import sys

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False

# WD
wd = r'C:/Users/Nick/Documents/Eubank'
os.chdir(wd)

#########################
# Body
#########################

gdb = wd + '/Outputs/20_georeferencing_users/georef.gdb/'
ap.env.overwriteOutput = True
ap.env.workspace = wd


#ap.CopyFeatures_management(gdb + 'thiessens_full', 'in_memory/test')
#ap.AddField_management(in_table = 'in_memory/test', field_name = "primarySiteID2", field_type = "FLOAT")
#ap.CalculateField_management(in_table = 'in_memory/test', field = 'primarySiteID2', 
#                             expression = "!primarySiteID!",
#                             expression_type = 'PYTHON_9.3')


# File shorthands
towers = gdb + r'towers'
wards = gdb + r'wards'
consts = gdb + r'consts'
country = gdb + r'country'
buffers = gdb + r'buffers'
tempfile = gdb + 'tempfile'
thiessens = gdb + 'thiessens_full'




# Now make buffer for clipping
bufferRadius = 35000
ap.Buffer_analysis(buffer_distance_or_field = bufferRadius, 
                   in_features = towers, 
                   out_feature_class = tempfile,
                   dissolve_option = "ALL")

ap.Clip_analysis(in_features= tempfile , clip_features = country, out_feature_class= buffers)
ap.Delete_management(in_data = tempfile )

# Thiessen and clip
# Replace a layer/table view name with a path to a dataset (which can be a layer file) or create the layer/table view within the script
# The following inputs are layers or table views: "towers"
ap.CreateThiessenPolygons_analysis(
    towers,
    tempfile,
    "ALL")
    
ap.Clip_analysis(in_features = tempfile,
                 clip_features = buffers, 
                 out_feature_class = thiessens)
                 
#Thin thiessen file towers
fieldObjList = ap.ListFields(thiessens)
fields = list()
for field in fieldObjList:
    if not field.required:
        if field.name != 'SITEID':
            fields.append(field.name)


ap.DeleteField_management(in_table = thiessens,
                          drop_field = fields)


ap.AddField_management(in_table = thiessens, field_name = "primarySiteID", field_type = "FLOAT")
ap.CalculateField_management(in_table = thiessens, field = 'primarySiteID', 
                             expression = "!SITEID!",
                             expression_type = 'PYTHON_9.3')

ap.DeleteField_management(in_table = thiessens,
                          drop_field = ['SITEID'])


ap.AddField_management(in_table = thiessens, field_name = "secondarySiteID", field_type = "FLOAT")


