# -*- coding: utf-8 -*-
from __future__ import division, print_function

import pandas as pd
import os
import sys
import arcpy as ap


# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)


###############
# Setup Functions
################

# Create layer


def setupForSecondOrder():
    for i in  ['towers', 'country', 'thiessens_full']:
        ap.MakeFeatureLayer_management(gdb_parallel + i, i)
    return "Successful installs!"



def secondOrderThiessenOmitting(omitted):
    query =  """ NOT "SITEID" = {} """.format(omitted)

    # Make layer minus one tower
    ap.MakeFeatureLayer_management(in_features = 'towers',
                                 out_layer = 'tempLayer',
                                 where_clause = query)


    # Create thiessens
    ap.CreateThiessenPolygons_analysis(
        in_features = 'tempLayer',
        out_feature_class = tempfile,
        fields_to_copy = 'ALL')


    # Create new buffer and clip to zambia limits
    bufferRadius = 35000
    ap.Buffer_analysis(buffer_distance_or_field = bufferRadius,
                   in_features = 'tempLayer',
                   out_feature_class = tempbuffer,
                   dissolve_option = "ALL")

    ap.Clip_analysis(in_features= tempbuffer ,
                     clip_features = 'country',
                     out_feature_class= tempbuffer_postCountry)

    # Clip thiessen
    ap.Clip_analysis(in_features = tempfile,
                     clip_features = tempbuffer_postCountry,
                     out_feature_class = gdb_parallel + 'tp_{}'.format(omitted)
                     )

    client = gdb_parallel[43]
    return 'site{} done, in gdb {}!'.format(omitted, client)

############
# Parallelize -- REQUIRES IPYTHON 3.2!
############

# Make databases and distribute base components
numClients = 3
import arcpy as ap
ap.env.overwriteOutput = True

for i in range(numClients):
    location = wd + '/outputs/20_georeferencing_users/'
    db = 'temp{}'.format(i)

    ap.CreateFileGDB_management(location,db , "CURRENT")
    gdb = wd+ '/outputs/20_georeferencing_users/georef.gdb/'
    gdb_parallel = wd+ '/outputs/20_georeferencing_users/temp{}.gdb/'.format(i)
    for z in  ['towers', 'country', 'thiessens_full']:
        ap.CopyFeatures_management(gdb + z, gdb_parallel + z)


# Start parallelization.
    # Rembmer to run "ipcluster start -n 3" first
from IPython import parallel
clients = parallel.Client()
clients.ids

# Views
dview = clients.direct_view()
dview.block = True
lview = clients.load_balanced_view()
lview.block = False



# Set each person's geo-database
for i in range(numClients):
    clients[i].execute('gdb_parallel="C:/Users/Nick/Documents/Eubank/outputs/20_georeferencing_users/temp{}.gdb/"'.format(i))


# Load libraries and such:
loadblock =['import arcpy as ap',
'import os',
'import time',
'ap.env.overwriteOutput = True',
"wd = r'/Volumes/Zambia/'",
'os.chdir(wd)',
'tempfile = "in_memory/tempfile"',
'tempbuffer = "in_memory/tempbuffer"',
'tempbuffer_postCountry = "in_memory/tempbuffer_postCountry"']

for z in loadblock:
    dview.execute(z)


# Run!

dview.apply(setupForSecondOrder)

sites = pd.read_csv('pt_data/cell/justActiveSites.csv')['SITEID'].tolist()
total_number = len(sites) - 1
returns = dict()
for i, site in enumerate(sites):
    returns[i] = lview.apply(secondOrderThiessenOmitting, site)
    sys.stdout.flush()
print('finished allocating jobs')
sys.stdout.flush()

i = 0
while i < total_number :
    if returns[i].ready():
        print('finished {}'.format(i))
        print(returns[i].get())
        sys.stdout.flush()
        i += 1




print('all done!')
