# -*- coding: utf-8 -*-
from __future__ import division, print_function
import pandas as pd
import os
import sys
import time
import arcpy as ap
# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#######
# Intersect!
#########

    # The plan is to merge things up, extract the siteids into the
    # secondary site it field, then drop everything else


ap.env.workspace = wd + '/outputs/20_georeferencing_users/temp.gdb'
temp = 'in_memory/intersectTempFile'
temp2 = 'in_memory/intersectTempFile2'

ap.CopyFeatures_management(wd + "/outputs/20_georeferencing_users/georef.gdb/thiessens_full", temp)

sites = pd.read_csv('pt_data/cell/justActiveSites.csv')['SITEID'].tolist()
ap.env.overwriteOutput = True


for run, i in enumerate(sites):
    t0 = time.clock()
    # Merge strings
    mergeString = "in_memory/intersectTempFile; tp_{}".format(i)
    print(mergeString)
    #sys.stdout.flush()

    # Intersect
    ap.Union_analysis(in_features = mergeString,
                      out_feature_class = temp2,
                      join_attributes = 'NO_FID')

    ap.CopyFeatures_management(temp2, temp)
    ap.DeleteFeatures_management(temp2)

    # Code block
    func = """def secondaryIf(primary, original_secondary, new_secondary, new_fid):
        if primary == {}:
            if new_fid != 0:
                return new_secondary
            else: return None
        else: return original_secondary""".format(i)

    query = "secondaryIf(!primarySiteID!, !secondarySiteID!, !SITEID!, !Input_FID!)"

    ap.CalculateField_management(in_table = temp,
                                    field = "secondarySiteID",
                                    expression = query,
                                    expression_type = "PYTHON",
                                    code_block = func)


    # Delete Field
    toDelete = ['Field1', 'Input_FID', 'SITEID', 'LONGITUDE', 'LATITUDE']
    ap.DeleteField_management(in_table = temp,
                          drop_field = toDelete)

    t1 = time.clock()
    print('run {}, site {}, took {:.2f} minutes'.format(run, i,(t1-t0)/60))


##########
# Now clean and process
#########


ap.CopyFeatures_management(in_features = temp,
                           out_feature_class = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal')



# Get rid of places that were in original file and never got a secondary site. For some reason, coded
# as secondarySiteID = 0 and primarySiteID = 0.
ap.CopyFeatures_management(in_features =  wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal',
                           out_feature_class = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2')

bad_rows = "primarySiteID = 0 AND secondarySiteID = 0"
ap.MakeFeatureLayer_management(in_features = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2',
                               where_clause = bad_rows,
                               out_layer = 'prob_rows')
ap.DeleteFeatures_management('prob_rows')


# Also get rid of slivers along outer edges of shapes. Almost all tiny save one.
edge_slivers = 'secondarySiteID IS NULL AND Shape_Area < 10'
ap.MakeFeatureLayer_management(in_features = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2',
                               where_clause = edge_slivers,
                               out_layer = 'slivers')
ap.DeleteFeatures_management('slivers')

# Here's the one apparently big one - -a ring all the way round a cirle.
# Also get rid of slivers along outer edges of shapes. Almost all tiny save one.
edge_slivers2 = 'secondarySiteID IS NULL AND Shape_Area < 1500 AND Shape_Area > 1400'
ap.MakeFeatureLayer_management(in_features = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2',
                               where_clause = edge_slivers2,
                               out_layer = 'slivers2')
ap.DeleteFeatures_management('slivers2')

# Here's another sliver that drops in intersect with admin
edge_slivers3 = 'secondarySiteID = 1047 AND Shape_Area < 67 AND Shape_Area > 66'
ap.MakeFeatureLayer_management(in_features = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2',
                               where_clause = edge_slivers3,
                               out_layer = 'slivers3')
ap.DeleteFeatures_management('slivers3')



# And one last TINY polygon that gets dropped when intersecting with wards
edge_slivers4 = 'secondarySiteID = 1076 AND Shape_Area < 0.0001'
ap.MakeFeatureLayer_management(in_features = wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2',
                               where_clause = edge_slivers4,
                               out_layer = 'slivers4')
ap.DeleteFeatures_management('slivers4')



ap.CopyFeatures_management(in_features =  wd + '/outputs/20_georeferencing_users/temp.gdb/semiFinal2',
                           out_feature_class = wd + '/outputs/20_georeferencing_users/georef.gdb/secondOrderThiessens')

ap.ExportXYv_stats(Input_Feature_Class = wd + '/outputs/20_georeferencing_users/georef.gdb/secondOrderThiessens',
                           Value_Field = ['primarySiteID', 'secondarySiteID'],
                           Delimiter = 'COMMA',
                           Add_Field_Names_to_Output = True,
                           Output_ASCII_File = wd + '/outputs/20_georeferencing_users/second_order_thiessen_siteidsonly.csv')




print('done')
