# -*- coding: utf-8 -*-
from __future__ import division, print_function
import pandas as pd
import os
import sys
import arcpy as ap

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################
ap.env.overwrite = True
ap.env.workspace = wd
gdb = wd + '/outputs/20_georeferencing_users/georef.gdb/'
# First, interescts with admin boundaries
coverage_1 =  'in_memory/thiessens_full'
coverage_2 =  'in_memory/secondOrderThiessens'


wards = 'in_memory/wards'
consts = 'in_memory/consts'
temp = 'in_memory/temp'

ap.Delete_management('in_memory')
for i in ['wards', 'consts', 'secondOrderThiessens', 'thiessens_full']:
    ap.CopyFeatures_management(in_features = gdb + i, 
                               out_feature_class = 'in_memory/' + i )


###
# Clean ward field names
fieldObjList = ap.ListFields(wards)
fields = list()
for field in fieldObjList:
    if not field.required:
        if field.name != 'wardCode' and field.name != 'constCode':
            fields.append(field.name)

ap.DeleteField_management(in_table = wards,
                          drop_field = fields)

ap.DeleteField_management(in_table = consts,
                          drop_field = ['constName'])

###

# Run loop of intersects!
ap.env.overwriteOutput = True
for admin in ['wards', 'consts']:
    for coverage in [coverage_1, coverage_2]:
        merge_string = '{}; in_memory/{}'.format(coverage, admin)
        print(merge_string)
        
        ap.Union_analysis(in_features = merge_string,
                          out_feature_class = temp,
                          join_attributes = 'NO_FID')
    
    
        # Get area
        ap.AddField_management(in_table = temp, field_name = "intersectArea", field_type = "FLOAT")
        
        area = "!shape.area!"
        ap.CalculateField_management(in_table = temp, 
                                     field = 'intersectArea', 
                                     expression = area,
                                     expression_type = 'PYTHON_9.3')
                                     
        
    
        
        if coverage == 'in_memory/thiessens_full': 
            output_string = 'firstOrder'
        if coverage == 'in_memory/secondOrderThiessens':
            output_string = 'secondOrder'
        

        ap.CopyFeatures_management( in_features = temp,
                                  out_feature_class = gdb + admin + '_intersect_' + output_string)


        print('output file: {}/outputs/20_georeferencing_users/thiessens_{}_{}.csv'.format(wd, output_string, admin) )
        
        
        columns =  ['primarySiteID', 'secondarySiteID', 'intersectArea', 'constCode']     
        
        if admin == 'wards': columns.append('wardCode')  
        
        ap.ExportXYv_stats(Input_Feature_Class = temp,
                           Value_Field = columns,
                           Delimiter = 'COMMA', 
                           Add_Field_Names_to_Output = True,
                           Output_ASCII_File = '{}/outputs/20_georeferencing_users/thiessens_{}_{}.csv'.format(wd, output_string, admin))
        
        
        
                              
                              
                              
                              