
clear
clear
set more off

*********************
* Ward data from the CSO was provided in some rather odd CSV formats with one sheet per variable, so this imports and reshapes each sheet individually.
* 	Note that the "de jure" / "de facto" distinction is "reported to live in home" versus "in home at time of survey". De jure seems
* 	closer to norm, so using that.
* ********************
capture program drop reshapeCSV
program reshapeCSV


	replace level = subinstr(level, "'", "", .)
	replace level = trim(level)
	replace level = proper(level)

	replace level = "Muchinga" if level == "Muchinga Province" & level[_n-1] == "Matero Constituency"


	drop if level == "Zambia"
	gen districtTag = 1 if regexm(level, "District")
	gen constituencyTag = 1 if regexm(level, "Constituency")
	gen provinceTag = 1 if regexm(level, "Province")
	gen wardTag = 1 if districtTag == . & constituencyTag == . & provinceTag == .


	set more off
	foreach x in district constituency province {
		sort ordering
		gen `x'Name = level if `x'Tag == 1
		replace `x'Name = `x'Name[_n-1] if `x'Name[_n]=="" & `x'Name[_n-1]!=""
		local properVersion = proper("`x'")
		replace `x'Name = subinstr(`x'Name, "`properVersion'", "",.)
		replace `x'Name = subinstr(`x'Name, " Central", "", .) if provinceTag==.
		replace `x'Name = subinstr(`x'Name, "  ", " ", .)
		replace `x'Name = trim(`x'Name)

	}

	foreach x in Name Tag {
		rename district`x' dist`x'
		rename constituency`x' const`x'
		rename province`x' prov`x'
	}

	keep if wardTag == 1
	rename level wardName
	drop *Tag
	drop order
end


*************
* Population
**************

* Get CSO Ward Population data
insheet using $zambia_inputs/Demographic/CSOCensus2010_WardAverages/wardPopulation_DeJure.csv, comma clear

	* First have to reformat this file, since has weird flat structure.
	gen ordering = _n

	foreach x in total male female {
		 rename `x' num_`x'
		capture rename `x'_pct pct_`x'
		capture  destring num_`x' , ignore(",") replace
		capture destring pct_`x', ignore(",") replace
	}

	**charlist num_total
	***
	* Reshape it
	******
	reshapeCSV





	renvars *, prefix(pop_)
	renvars *Name, predrop(4)

	count
	local popCount = `r(N)'

	order dist const ward
	sort distName constName wardName

save $zambia/intermediate_data/35_demographics/temp_wardPopulation, replace

*************
* Ethnicity
**************

* Get CSO Ward Population data
insheet using $zambia_inputs/Demographic/CSOCensus2010_WardAverages/wardEthnicity_DeJure.csv, comma clear

	* First have to reformat this file, since has weird flat structure.
	gen ordering = _n


	rename v5 pct_bemba
	rename v7 pct_tonga
	rename v9 pct_northwestern
	rename v11 pct_barotse
	rename v13 pct_nyanja
	rename v15 pct_mambwe
	rename v17 pct_tumbukalan
	rename v19 pct_english
	rename v21 pct_other
	rename v23 pct_na
	rename v25 pct_notStated
	rename v27 pct_majorRacialGroup
		drop percent

	rename bembaspeaking num_bemba
	rename tongaspeaking num_tonga
	rename northwestern num_northwestern
	rename barotse num_barotse
	rename nyanja num_nyanja
	rename mambwel num_mambwe
	rename tumbukalanguage num_tumbuka
	rename english num_english
	rename otherlan num_other
	rename majorracialgroup num_majorRacialGroup
	rename notapplicable num_na
	rename notstated num_notStated
	rename total num_total


	foreach x of varlist num_* pct_* {
		capture{
			replace `x' = "" if `x' =="*"
			replace `x' = "" if `x' == "-"
			destring `x' , replace ignore(",")
		}
	}



	*****
	* Reshape it
	******
	reshapeCSV



	renvars *, prefix(eth_)
	renvars *Name, predrop(4)


	count
	local ethCount = `r(N)'

	order dist const ward
	sort distName constName wardName


save $zambia/intermediate_data/35_demographics/temp_wardEthnicity, replace





*************
* Language
**************

* Get CSO Ward Population data
insheet using $zambia_inputs/Demographic/CSOCensus2010_WardAverages/wardLanguage_DeJure.csv, comma clear

	* First have to reformat this file, since has weird flat structure.
	gen ordering = _n

	rename v5 pct_bemba
	rename v7 pct_tonga
	rename v9 pct_northwestern
	rename v11 pct_barotse
	rename v13 pct_nyanja
	rename v15 pct_mambwe
	rename v17 pct_tumbukalan
	rename v19 pct_english
	rename v21 pct_other
	rename v23 pct_na
	rename v25 pct_notStated
	rename v27 pct_majorRacialGroup
		drop percent

	rename bembaspeaking num_bemba
	rename tongaspeaking num_tonga
	rename northwestern num_northwestern
	rename barotse num_barotse
	rename nyanja num_nyanja
	rename mambwel num_mambwe
	rename tumbukalanguage num_tumbuka
	rename english num_english
	rename otherlan num_other
	rename majorracialgroup num_majorRacialGroup
	rename notapplicable num_na
	rename notstated num_notStated
	rename total num_total


	foreach x of varlist num_* pct_* {
		capture{
			replace `x' = "" if `x' =="*"
			replace `x' = "" if `x' == "-"
			destring `x' , replace ignore(",")
		}
	}



	*****
	* Reshape it
	******
	reshapeCSV


	renvars *, prefix(lang_)
	renvars *Name, predrop(5)

	count
	local langCount = `r(N)'

	order dist const ward
	sort distName constName wardName


save $zambia/intermediate_data/35_demographics/temp_wardLanguages, replace



****************
* Combine
***************
* Check sizes almost equal


assert  `popCount' == `ethCount'
assert `ethCount' == `langCount'

use $zambia/intermediate_data/35_demographics/temp_wardLanguages ,clear
sort distName constName wardName
merge 1:1 distName constName wardName using $zambia/intermediate_data/35_demographics/temp_wardEthnicity
assert _m==3
drop _m
sort distName constName wardName
merge 1:1 distName constName wardName using $zambia/intermediate_data/35_demographics/temp_wardPopulation
assert _m==3
drop _m
compress


save $zambia/intermediate_data/35_demographics/wardsWithoutGIS.dta, replace


******************
* Clean up
***************


foreach x in Languages Ethnicity Population Grouped {
	capture erase $zambia/intermediate_data/35_demographics/temp_ward`x'.dta
}
