
clear
clear
set more off

*********************
* Ward data from the CSO was provided in some rather odd CSV formats with one sheet per variable, so this imports and reshapes each sheet individually.
* 	Note that the "de jure" / "de facto" distinction is "reported to live in home" versus "in home at time of survey". De jure seems
* 	closer to norm, so using that.
* ********************
capture program drop reshapeCSV
program reshapeCSV


	replace level = subinstr(level, "'", "", .)
	replace level = trim(level)
	replace level = proper(level)
	replace level = "Muchinga" if level == "Muchinga Province" & level[_n-1] == "Matero Constituency"

	drop if level == "Zambia"
	gen districtTag = 1 if regexm(level, "District")
	gen constituencyTag = 1 if regexm(level, "Constituency")
	gen provinceTag = 1 if regexm(level, "Province")
	gen wardTag = 1 if districtTag == . & constituencyTag == . & provinceTag == .


	set more off
	foreach x in district constituency province {
		sort ordering
		gen `x'Name = level if `x'Tag == 1
		replace `x'Name = `x'Name[_n-1] if `x'Name[_n]=="" & `x'Name[_n-1]!=""
		local properVersion = proper("`x'")
		replace `x'Name = subinstr(`x'Name, "`properVersion'", "",.)
		replace `x'Name = subinstr(`x'Name, " Central", "", .) if provinceTag==.
		replace `x'Name = subinstr(`x'Name, "  ", " ", .)
		replace `x'Name = trim(`x'Name)

	}

	foreach x in Name Tag {
		rename district`x' dist`x'
		rename constituency`x' const`x'
		rename province`x' prov`x'
	}

	keep if constTag == 1
	drop level
	drop *Tag
	drop order
end


*************
* Population
**************

* Get CSO Ward Population data
insheet using $zambia_inputs/Demographic/CSOCensus2010_WardAverages/wardPopulation_DeJure.csv, comma clear

	* First have to reformat this file, since has weird flat structure.
	gen ordering = _n

	foreach x in total male female {
		 rename `x' num_`x'
		capture rename `x'_pct pct_`x'
		capture  destring num_`x' , ignore(",") replace
		capture destring pct_`x', ignore(",") replace
	}

	**charlist num_total
	***
	* Reshape it
	******

	reshapeCSV

	keep num_total *Name
	rename num_total population
	order provName distName constName
	sort distName constName


	***************
	* Harmonize names
	* 	Want to modify distName / constName / wardName to allow merging so I can assign
	* 	const codes to each observation.
	***************


	* Wards have sometimes been re-assigned across districts.
	* This is coded with post-2010 assignments. I want 2010 assignments (that's what's in wards)
		* TO REVERSE TO 2010:
		* Chipili -> Mwense
		* Mwansabombwe -> Kawambwa
		* Rufunsa -> Chongwe
		* Sibuyunji -> Mumwa
		* Mafinga -> Isoka
		* Ikelenge -> Mwinilunga

	replace distName = "Mwense" if distName == "Chipili"
	replace distName = "Kawambwa" if distName == "Mwansabombwe"
	replace distName = "Chongwe" if distName == "Rufunsa"
	replace distName = "Mumbwa" if distName == "Sinjembela"
	replace distName = "Isoka" if distName == "Mafinga"
	replace distName = "Mwinilunga" if distName == "Ikelenge"


	* Some region / province modifications -- Muchina was created from parts of northern and eastern.
		replace provName = "Northern" if provName =="Muchinga" & distName != "Chama"
		replace provName = "Eastern" if provName =="Muchinga" & distName == "Chama"

	* oddly two constituencies in Eastern flipped -- checked against two sources to confirm.
	replace constName = "temp" if constName == "Msanzala"
	replace constName = "Msanzala" if constName == "Petauke"
	replace constName = "Petuake" if constName == "temp"

	* Three in Mansa swapped too. However, since I"m only using constituency totals
	* for places with missing wards and there are none here,  I don't need to worry
	* about rectifying these here -- sufficient to do at ward level.
	* But gonna drop to be safe so I never accidentally use!
	drop if constName == "Bahati"
	drop if constName == "Mansa"
	*replace constName = "Bahati" if distName == "Mansa" & wardName == "Chibeleka"
	*replace constName = "Bahati" if distName == "Mansa" & wardName == "Lukangaba"
	*replace constName = "Mansa" if distName == "Mansa" & wardName == "Mansa"
	*replace constName = "Mansa" if distName == "Mansa" & wardName == "Myulu"


	* Lots of spelling type issues across multiple levels.
	foreach x in distName constName {
		replace `x' = trim(`x')
		replace `x' = "Mufulira" if `x' == "Mufurila"
		replace `x' = "Bwana Mkubwa" if `x' == "Bwana Mkumbwa"
		replace `x' = "Chiengi" if `x' == "Chienge"
		replace `x' = "Kawambwa" if `x' == "Kawambwa"
		replace `x' = "Bangeulu" if `x' == "Bangweulu"
		replace `x' = "Northwestern" if `x' == "North-Western"
		replace `x' = "Shiwangadu" if `x' =="Shiwangandu"
		replace `x' = "Isoka" if `x' =="Izoka"
		replace `x' = "Lubasenshi" if `x' == "Lubansenshi"
		replace `x' = "Mazubuka" if `x' == "Mazabuka"
		replace `x' = "Chongwe" if `x' == "Congwe"
		replace `x' = "Mazabuka" if `x' == "Mazubuka"
		replace `x' = "Petauke" if `x' == "Petuake"
	}
	replace constName = "Kabwe Central" if constName == "Kabwe"


		replace constName = "Kalomo Central" if constName == "Kalomo"
		replace constName = "Solwezi Central" if constName == "Solwezi"
		replace constName = "Lusaka Central" if constName == "Lusaka"
		replace constName = "Kaoma Central" if constName == "Kaoma"

		***************
		* Get GIS codes
		**************

		preserve
		insheet using $zambia_inputs/GIS/Zambia_ConstituenciesAndWards_2006to2010_AttributeTable.csv, comma clear

		keep constcode constname distname province
		duplicates drop constcode, force


		rename constcode constCode
		rename constname constName

		rename distname distName


		keep distName constName constCode
		sort  distName constName constCode

		tempfile giscodes
		save `giscodes', replace

		restore
sort distName constName
merge 1:1 distName constName using `giscodes'
tab _m
br if _m !=3
assert _m != 1
drop _m

keep constCode population
save $zambia/intermediate_data/35_demographics/constPopulation2010, replace
