
clear
set more off

********
* All master codes come from 2006 maps
********

insheet using $zambia_inputs/GIS/Zambia_ConstituenciesAndWards_2006to2010_AttributeTable.csv, comma clear
drop fid_ objectid wardnum

rename wardcode wardCode
rename wardname wardName

rename constcode constCode
rename constname constName

rename distname distName

replace wardName = proper(wardName)



drop if  wardName == "Missing" | wardName == "Map Labels Unclear"


keep distName constName wardName wardCode
sort  distName constName wardName

tempfile giscodes
save `giscodes', replace

********************
* Now prep for merge
*******************

use $zambia/intermediate_data/35_demographics/wardsWithoutGIS.dta, clear

drop *_pct_*
* keep distName constName wardName provName

	***************
	* Harmonize names
	* 	Want to modify distName / constName / wardName to allow merging so I can assign
	* 	const codes to each observation.
	***************


	* Wards have sometimes been re-assigned across districts.
	* This is coded with post-2010 assignments. I want 2010 assignments (that's what's in wards)
		* TO REVERSE TO 2010:
		* Chipili -> Mwense
		* Mwansabombwe -> Kawambwa
		* Rufunsa -> Chongwe
		* Sibuyunji -> Mumwa
		* Mafinga -> Isoka
		* Ikelenge -> Mwinilunga

	replace distName = "Mwense" if distName == "Chipili"
	replace distName = "Kawambwa" if distName == "Mwansabombwe"
	replace distName = "Chongwe" if distName == "Rufunsa"
	replace distName = "Mumbwa" if distName == "Sinjembela"
	replace distName = "Isoka" if distName == "Mafinga"
	replace distName = "Mwinilunga" if distName == "Ikelenge"


	* Some region / province modifications -- Muchina was created from parts of northern and eastern.
		replace provName = "Northern" if provName =="Muchinga" & distName != "Chama"
		replace provName = "Eastern" if provName =="Muchinga" & distName == "Chama"



	* oddly two constituencies in Eastern flipped -- checked against two sources to confirm.
	replace constName = "temp" if constName == "Msanzala"
	replace constName = "Msanzala" if constName == "Petauke"
	replace constName = "Petuake" if constName == "temp"

	* Three in Mansa swapped too
	replace constName = "Bahati" if distName == "Mansa" & wardName == "Chibeleka"
	replace constName = "Bahati" if distName == "Mansa" & wardName == "Lukangaba"
	replace constName = "Mansa" if distName == "Mansa" & wardName == "Mansa"
	replace constName = "Mansa" if distName == "Mansa" & wardName == "Myulu"


	* Lots of spelling type issues across multiple levels.
	foreach x in distName constName wardName {
		replace `x' = trim(`x')
		replace `x' = "Mufulira" if `x' == "Mufurila"
		replace `x' = "Bwana Mkubwa" if `x' == "Bwana Mkumbwa"
		replace `x' = "Chiengi" if `x' == "Chienge"
		replace `x' = "Kawambwa" if `x' == "Kawambwa"
		replace `x' = "Bangeulu" if `x' == "Bangweulu"
		replace `x' = "Northwestern" if `x' == "North-Western"
		replace `x' = "Shiwangadu" if `x' =="Shiwangandu"
		replace `x' = "Isoka" if `x' =="Izoka"
		replace `x' = "Lubasenshi" if `x' == "Lubansenshi"
		replace `x' = "Mazubuka" if `x' == "Mazabuka"
		replace `x' = "Chongwe" if `x' == "Congwe"
		replace `x' = "Mazabuka" if `x' == "Mazubuka"
		replace `x' = "Petauke" if `x' == "Petuake"
	}
	replace constName = "Kabwe Central" if constName == "Kabwe"

	* Ward-level spelling
	replace wardName = "Naviruli" if wardName=="Naviluri" & constName == "Chadiza"
	replace wardName = "Chambi/Mandalo" if wardName=="Chambi Mandalo" & constName == "Chavuma"
	replace wardName = "Lukolwe/Musumba" if wardName=="Lukolwe Musumba" & constName == "Chavuma"
	replace wardName = "Chinkokomene" if wardName=="Chikonkomene" & constName == "Chisamba"
	replace wardName = "Mushishi" if wardName=="Muswishi" & constName == "Chisamba"
	replace wardName = "Chibimbi" if wardName=="Chibombo" & constName == "Keembe"
	replace wardName = "Kalungwishi" if wardName=="Kulungwishi" & constName == "Chiengi"
	replace wardName = "Joseph Mwila" if wardName=="Joseph Mwilwa" & constName == "Chililabombwe"
	replace wardName = "Kamina" if wardName=="Kamima" & constName == "Chililabombwe"
	replace wardName = "iyanda" if wardName=="Miyanda" & constName == "Chililabombwe"
	replace wardName = "G Chifwembe" if wardName=="Gibson Chimfwembe" & constName == "Chingola"
	replace wardName = "Chabeshi" if wardName == "Chambeshi" & constName == "Malole"
	replace wardName = "Chana-Chamuhinga" if wardName == "Chana Chamuhinga" & constName == "Ikelenge"
	replace wardName = "Chansunsu" if wardName == "Chansusu" & constName == "Mansa"
	replace wardName = subinstr(wardName, " Central", "", .)
	replace wardName = "Chibwelelo" if wardName == "Chibwelo" & constName == "Kapiri Mposhi"
	replace wardName = "Chifunauli" if wardName == "Chifunabuli" & constName == "Chifunabuli"
	replace wardName = "Chipaba" if wardName == "Chapaba" & constName == "Mkushi South"
	replace wardName = "Chipili" if wardName == "Chimpili" & constName == "Pambashe"
	replace wardName = "Chimpundu" if wardName == "Chimpunda" & constName == "Shiwangadu"
	replace wardName = "Chishamwamba" if wardName == "Chisha Mwamba" & constName == "Mporokoso"
	replace wardName = "Chisela" if wardName == "Chishela" & constName == "Chimbamilonga"
	replace wardName = "Chisi" if wardName == "Chishi" & constName == "Chifunabuli"
	replace wardName = "Chitokokoki" if wardName == "Chitokoloki" & constName == "Zambezi East"
	replace wardName = "Chiwanza" if wardName == "Chiwaza" & constName == "Nakonde"
	replace wardName = "Chizera" if wardName == "Chizela" & constName == "Mufumbwe"
	replace wardName = "David Kaunda" if wardName == "David Kaunda" & constName == "Mufulira"
	replace wardName = "David Kaunda" if wardName == "David Lunda" & constName == "Kantanshi"
	replace wardName = "Dr Mubitana" if wardName == "Dr. Mubitana" & constName == "Livingstone"
	replace wardName = "Hantotola" if wardName == "Hatontola" & constName == "Monze"
	replace wardName = "Hufwa / Hamapande" if wardName == "Hufwa/Hamapande" & constName == "Monze"
	replace wardName = "Ibwe Munyama" if wardName == "Ibwemunyama" & constName == "Siavonga"
	replace wardName = "Kabi Pupu" if wardName == "Kabipupu" & constName == "Mufumbwe"
	replace wardName = "Kavid Ramushu" if wardName == "David Ramushu" & constName == "Kabwe Central"
	replace wardName = "Kalonga" if wardName == "Kalongola" & constName == "Kabwe Central"
	replace wardName = "Kamakoko" if wardName == "Kamakuku" & constName == "Kasempa"
	replace wardName = "Kapumba" if wardName == "Kampumba" & constName == "Kapiri Mposhi"
	replace wardName = "Kapiri Central" if wardName == "Kapiri Mposhi" & constName == "Kapiri Mposhi"
	replace wardName = "Kasongole" if wardName == "Kasongele" & constName == "Chifunabuli"
	replace wardName = "Katabi" if wardName == "Kataba" & constName == "Nalolo"
	replace wardName = "Kwancha" if wardName == "Kwacha" & constName == "Kankoyo"
	replace wardName = "Luela" if wardName == "Luena" & constName == "Kawambwa"
	replace wardName = "Lukangaba" if wardName == "Lukangaba" & constName == "Mansa"
	replace wardName = "Lyamakumbi" if wardName == "Lyamakumba" & constName == "Nalolo"
	replace wardName = "Lutiwi" if wardName == "Lutwi" & constName == "Kalabo"
	replace wardName = "Lusubwe" if wardName == "Lusumbwe" & constName == "Chembe"
	replace wardName = "Manchanvwa" if wardName == "Manchamvwa" & constName == "Siavonga"
	replace wardName = "Mateyo Mseka" if wardName == "Mateyo Mzeka" & constName == "Petauke"
	replace wardName = "Mosofu" if wardName == "Masofu" & constName == "Mkushi North"
	replace wardName = "Lukusanshi" if wardName == "Lukusashi" & constName == "Muchinga"
	replace wardName = "Matondo" if wardName == "Matondo Nyachikayi" & constName == "Zambezi West"
	replace wardName = "Mbabala" if wardName == "Mbambala" & constName == "Chifunabuli"
	replace wardName = "Miko Mfwa" if wardName == "Mikomfwa" & constName == "Luanshya"
	replace wardName = "Misheshi" if wardName == "Miseshi" & constName == "Nkana"
	replace wardName = "Milaushi" if wardName == "Milyashi" & constName == "Roan"
	replace wardName = "Nkaliva" if wardName == "Mkaliva" & constName == "Feira"
	replace wardName = "Moto Moto" if wardName == "Motomoto" & constName == "Mbala"
	replace wardName = "Muchinga" if wardName == "Muchinda" & constName == "Serenje"
	replace wardName = "Mukubwe" if wardName == "Mukumbwe" & constName == "Kapiri Mposhi"
	replace wardName = "Mukunashi" if wardName == "Mukunanshi" & constName == "Kasempa"
	replace wardName = "Musi O Tunya" if wardName == "Musi-Oa-Tunya" & constName == "Livingstone"
	replace wardName = "Mushituwamboo" if wardName == "Mushitu-Wamboo" & constName == "Lubasenshi"
	replace wardName = "Munshibemba" if wardName == "Mushibemba" & constName == "Mkushi North"
	replace wardName = "Mwangila" if wardName == "Mwangaila" & constName == "Kapoche"
	replace wardName = "Munwakubili" if wardName == "Mwanuakabili" & constName == "Chinsali"
	replace wardName = "Nkandabwe" if wardName == "Nkamdabwe" & constName == "Sinazongwe"
	replace wardName = "Nkonkola" if wardName == "Nkokola" & constName == "Magoye"
	replace wardName = "Nkombashi" if wardName == "Nkomashi" & constName == "Mkushi South"
	replace wardName = "Nkulumashimba" if wardName == "Nkulumashiba" & constName == "Roan"
	replace wardName = "Nthitimila" if wardName == "Nthintimila" & constName == "Lundazi"
	replace wardName = "Iyanda" if wardName == "iyanda" & constName == "Chililabombwe"
	replace wardName = "Kapililonge" if wardName == "Kapililonga" & constName == "Isoka"
	replace wardName = "Sasamwenjue" if wardName == "Sasamwenje" & constName == "Isoka"
	replace wardName = "Muungu" if wardName == "Mungu" & constName == "Kafue"
	replace wardName = "Shabusale" if wardName == "Shabusele" & constName == "Kafue"
	replace wardName = "Chisupa" if wardName == "Remmy Chisupa" & constName == "Kalulushi"
	replace wardName = "Shitwe" if wardName == "Shitwa" & constName == "Kaoma"
	replace wardName = "Luanchele" if wardName == "Lwanchele" & constName == "Kapiri Mposhi"
	replace wardName = "Kikonkomeme" if wardName == "Kikonkomene" & constName == "Kasempa"
	replace wardName = "Mbelauke" if wardName == "Nselauke" & constName == "Kasempa"
	replace wardName = "Nyamasasonkho" if wardName == "Nyamasonkho" & constName == "Sinda"
	replace wardName = "Nthumbachushi" if wardName == "Ntumbachushi" & constName == "Kawambwa"
	replace wardName = "Parkland" if wardName == "Parklands" & constName == "Nkana"
	replace wardName = "Kapilinsanga" if wardName == "Kapilisanga" & constName == "Chasefu"
	replace wardName = "Luwelezi" if wardName == "Luwerezi" & constName == "Chasefu"
	replace wardName = "Vuli" if wardName == "Vuu" & constName == "Lundazi"
	replace wardName = "Wachitangati" if wardName == "Wachitangachi" & constName == "Lumezi"
	replace wardName = "Itembo" if wardName == "Itemba" & constName == "Chembe"
	replace wardName = "Mupamazi" if wardName == "Mupamadzi" & constName == "Mfuwe"
	replace wardName = "Mumbulama" if wardName == "Mumbuluma" & constName == "Mporokoso"
	replace wardName = "Nchelenje" if wardName == "Nchelenge" & constName == "Lunte"
	replace wardName = "Mulundu" if wardName == "Murundu" & constName == "Kantanshi"
	replace wardName = "Shiohanzu" if wardName == "Shichanzu" & constName == "Nangoma"
	replace wardName = "Lwamuloba" if wardName == "Luamuloba" & constName == "Mulobezi"
	replace wardName = "Mulima" if wardName == "Mulimya" & constName == "Siavonga"
	replace wardName = "Lukunyi" if wardName == "Lunkunyi" & constName == "Zambezi East"
	replace wardName = "Mushinga" if wardName == "Munshishinga" & constName == "Lupososhi"
	replace wardName = "Itandashi" if wardName == "Ntandashi" & constName == "Lupososhi"
	replace wardName = "Lwezi" if wardName == "Luezi" & constName == "Nyimba"
	replace wardName = "Chilimanyama" if wardName == "Chimanyama" & constName == "Petauke"
	replace wardName = "Mateyo Mseka" if wardName == "Mateyo Mzeka" & constName == "Msanzala"
	replace wardName = "Simbo" if wardName == "Nsimbo" & constName == "Petauke"
	replace wardName = "Pabekabesa" if wardName == "Pabe Kabesa" & constName == "Mwense"
	replace wardName = "Lwandi" if wardName == "Luandi" & constName == "Mbala"

	replace wardName = "Chavuma Central" if wardName == "Chavuma" & constName == "Chavuma"
	replace constName = "Kaoma Central" if constName == "Kaoma"
	replace constName = "Kalomo Central" if constName == "Kalomo"
	replace constName = "Lusaka Central" if constName == "Lusaka"
	replace wardName = "Dambwa Central" if wardName == "Dambwa" & constName == "Livingstone"
	replace wardName = "Musi O Tunya" if wardName == "Musi O Tunya" & constName == "Livingstone"
	replace wardName = "Mazabuka Central" if wardName == "Mazabuka" & constName == "Mazabuka"
	replace wardName = "Mpulungu Central" if wardName == "Mpulungu" & constName == "Mpulungu"
	replace wardName = "Namwala Central" if wardName == "Namwala" & constName == "Namwala"
	replace wardName = "Upper Lunsemfwa" if wardName == "Upper Lunsenfwa" & constName == "Mkushi North"


	* now some more complicated / questionable merges. All made by process of elimination.
	replace wardName = "Lutondo" if wardName == "Kapyanga" & constName == "Mwembezhi"
	replace wardName = "Mfinshe" if wardName == "Musensenshe" & constName == "Malole"
	replace wardName = "Chamfubu" if wardName == "Chibamba" & constName == "Malole"
	replace wardName = "Katangashi" if wardName == "Mulelenshi" & constName == "Mansa"


	**************************
	* Places that are merges of distinct wards
	**************************
	duplicates report distName constName wardName
	assert `r(unique_value)' == `r(N)'
	local count1 = `r(N)'


	replace wardName = "Merged Wards" if distName == "Chinsali" & constName == "Chinsali" & (wardName == "Ichinga" | wardName == "Nkakula")
	replace wardName = "Merged Wards" if distName == "Chinsali" & constName == "Shiwangadu" & (wardName == "Muchinga" | wardName == "Chandaula")
	replace wardName = "Merged Wards" if distName == "Isoka" & constName == "Isoka" & (wardName == "Itukuta" | wardName == "Milongo")
	replace wardName = "Merged Wards" if distName == "Lundazi" & constName == "Lumezi" & (wardName == "Chamtowa" | wardName == "Kachama")
	replace wardName = "Merged Wards" if distName == "Lundazi" & constName == "Lundazi" & (wardName == "Msuzi" | wardName == "Mkomba")
	replace wardName = "Merged Wards" if distName == "Mansa" & constName == "Mansa" & (wardName == "Muchinka" | wardName == "Chilyapa")
	replace wardName = "Merged Wards" if distName == "Mkushi" & constName == "Mkushi South" & (wardName == "Chingombe" | wardName == "Kamimbya")
	replace wardName = "Merged Wards" if distName == "Mpika" & constName == "Mpika" & (wardName == "Musakanya" | wardName == "Lubambala")
	replace wardName = "Merged Wards" if distName == "Mporokoso" & constName == "Mporokoso" & (wardName == "Mikomba" | wardName == "Kapumo")


	replace wardName = "Merged Wards" if distName == "Choma" & constName == "Choma" & (wardName == "Kalundana" | wardName == "Simacheche" | wardName == "Sikalundu" | wardName == "Mubula")
	replace wardName = "Merged Wards" if distName == "Mongu" & constName == "Mongu" & (wardName == "Kanyonyo" |wardName == "Kambule" | wardName == "Lewanika"|wardName == "Mulambwa" | wardName == "Imwiko")

	collapse (sum) *_num_*, by (provName distName constName wardName)

	count
	local count2 = `r(N)'
	display `count1' - `count2'
	assert (`count1' - `count2') == 16


sort  distName constName wardName
merge 1:1  distName constName wardName using `giscodes'


* Residual problems: 1 unmatched from GIS
	* Mpongwe / Impumbu: Not in census data!

keep if _m == 3

sort wardCode
save $zambia/intermediate_data/35_demographics/wards_2010.dta, replace
