
clear
set more off


***
* Individual level vars
***

use "$zambia/intermediate_data/35_demographics/census2010_individ_clean.dta", clear
* regligion
gen protestant = (p11_religion == 2)
gen rural = region==1

tab p11_religion, gen(relig_)

local i = 1
foreach x in "Catholic" "Protestant" "Muslim" "Hindu" "Buddhist" "Bahai Faith" "Other" "None" {
	label var relig_`i' "`x'"
	local i = `i' + 1
}

label var p11_religion "Distribution of Religious Identities"
latab p11_religion, tf("$zambia_results/religion_dist") replace dec(2)

preserve
	gen dev_enrolled = (p27_attending_school==1) if p27_attending_school!=. & p5_age >= 5 & p5_age <=15
	collapse (mean) protestant educ_* dev_enrolled rural relig_*, by(constCode)
	label var protestant "Share Protestant"

	sum rural
	sort constCode
	tempfile religion_and_educ
	save `religion_and_educ', replace
restore


preserve
	gen dev_enrolled = (p27_attending_school==1) if p27_attending_school!=. & p5_age >= 5 & p5_age <=15
	collapse (mean)  educ_* dev_enrolled, by(constCode rural)

	reshape wide educ_* dev_*, i(constCode) j(rural)
	renvars *0, postsub("0" "_urban")
	renvars *1, postsub("1" "_rural")

	sort constCode
	tempfile religion_and_educ2
	save `religion_and_educ2', replace
restore


* Infant mortality

preserve
	keep constCode p43* p44* p45*
	gen born_m = p43m_past_yr_in_hh + p44m_past_yr_elsewhere + p45m_past_year_died
	gen died_m = p45m_past_year_died
	gen born_f = p43f_past_yr_in_hh + p44f_past_yr_elsewhere + p45f_past_year_died
	gen died_f = p45f_past_year_died

	collapse (sum) born_m (sum)born_f (sum)died_m (sum)died_f , by(constCode)
	gen dev_infant_mortality = (died_m + died_f)/(born_m +born_f + died_m + died_f)
	keep dev_* constCode
	sort constCode
	tempfile infant
	save `infant', replace
restore


preserve
	keep constCode rural p43* p44* p45*
	gen born_m = p43m_past_yr_in_hh + p44m_past_yr_elsewhere + p45m_past_year_died
	gen died_m = p45m_past_year_died
	gen born_f = p43f_past_yr_in_hh + p44f_past_yr_elsewhere + p45f_past_year_died
	gen died_f = p45f_past_year_died

	collapse (sum) born_m (sum)born_f (sum)died_m (sum)died_f , by(constCode rural)
	gen dev_infant_mortality = (died_m + died_f)/(born_m +born_f + died_m + died_f)

	keep dev_* constCode rural

	reshape wide dev_*, i(constCode) j(rural)
	renvars *0, postsub("0" "_urban")
	renvars *1, postsub("1" "_rural")


	sort constCode
	tempfile infant2
	save `infant2', replace
restore



* Industry Frac
decode p35_industry, gen(in_string)

drop if in_string == "Not Stated" | in_string == ""

gen manufacturing = regexm(in_string, "Manufacture")
foreach x in "Construction" "Spinning, weaving" "Manufacturing" "Sawmilling" ///
	"other construction" "Buildind completion" "Repair of fabricated metal products" ///
	"specialised construction"{
	replace manufacturing = 1 if regexm(in_string, "`x'")==1
}

gen farming = 0
foreach x in "crop" "Farm" "farm" "animal" "Animal" "Fishing" "forestry" "Logging" {
	replace farming = 1 if regexm(in_string, "`x'")==1
}



gen service = 0
foreach x in "Retail" "service activities" "Activities of households as employers" "care activities" ///
			 "Provision of services" "education" "Maintenance and repair" "land transport" ///
			 "Private security" "cleaning" "Hospital activities" "Other human health" ///
			 "Creative, arts and entertainment" "Cleaning activities" "Electric power generation" ///
			 "Trusts, funds and" "Legal activities" "administrative" "Administration of the state" ///
			 "Beverage serving" "Wired telecommunications activities" {
	replace service = 1 if regexm(in_string, "`x'") == 1
}

gen mining = 0
foreach x in "Mining" "mining" "Quarrying" {
	replace mining = 1 if regexm(in_string, "`x'") == 1
}

local i = 0
gen industry = .
foreach x in manufacturing farming service mining {
	replace industry =  `i' if `x' ==1
	local proper_name = proper("`x'")
	label define industry `i'"`proper_name'", modify
	local i = `i'+1
}
label values industry industry
tab industry, m

label var industry "Distribution of Industries of Employment"
latab industry, tf("$zambia_results/industry_dist") replace dec(2)

bysort p35_industry: gen size = _N
tab p35_industry if industry == . & size > 400
drop size


* Make herf:
bysort constCode: gen denom = _N
bysort industry constCode: gen share = (_N /  denom)
assert share >=0 & share <= 1
gen share_sq = share*share


bysort constCode: egen max_share = max(share)

* One per industry
egen tag = tag(industry constCode)
keep if tag == 1

* Agg in each constituency
bysort constCode: egen industry_frac = sum(share_sq)
replace industry_frac = 1-industry_frac
duplicates drop constCode, force
label var industry_frac "Employment Frac"



corr max_share industry_frac
assert r(rho) < 0
drop max_share

* save
keep constCode industry_frac
sort constCode
tempfile industry_frac
save `industry_frac', replace


***************
* Household vars -- weight by size
**************

use "$zambia/intermediate_data/35_demographics/census2010_individ_clean.dta", clear
keep constCode household_serial_number
gen hh_size=1
collapse (sum) hh_size, by(constCode household_serial_number)
sort constCode household_serial_number
tempfile size
save `size', replace

use "$zambia/intermediate_data/35_demographics/census2010_hh_clean.dta", clear
drop if inlist(h5_occupancy , 4,5,6)
sort constCode household_serial_number
merge 1:1 constCode household_serial_number using `size'
assert _m==3
drop _m

*****
* Make dev vars for comparison to census 2000
* Some redundant, but with right names
******
gen tdev_protectedwater = inlist(h7a_water_supply_hh, 1,2,3,4,5) if h7a_water_supply_hh!=.
gen tdev_eleclight = (hh1a_lighting == 1)  if  hh1a_lighting!=.
gen tdev_thatchroof = (h2_roof == 1) if h2_roof!=.
gen tdev_mudfloor = (h4_floor == 5) if h4_floor !=.
gen tdev_pca_index = hh_pca_wealth

* Aggregate -- need to weight by hh size.

count
expand hh_size
sort constCode household_serial_number
count
*br constCode household_serial_number hh_size



* urban-rural
gen rural = region==1

preserve
	bysort constCode rural: egen wealth_mean = mean( hh_pca_wealth)
	bysort constCode rural: egen wealth_sd = sd(hh_pca_wealth)

	foreach x in protectedwater eleclight thatchroof mudfloor pca_index {
		bysort constCode rural : egen dev_`x'=mean(tdev_`x')
	}


	keep constCode rural wealth_mean wealth_sd dev_*
	duplicates drop constCode rural, force
	reshape wide wealth_mean wealth_sd dev_*, i(constCode) j(rural)

	renvars *0, postsub("0" "_urban")
	renvars *1, postsub("1" "_rural")

	sort constCode
	tempfile urban_rural_devs
	save `urban_rural_devs'
restore

* Straightup -- const-level

bysort constCode : egen wealth_mean = mean( hh_pca_wealth)
bysort constCode : egen wealth_sd = sd(hh_pca_wealth)

foreach x in protectedwater eleclight thatchroof mudfloor pca_index {
	bysort constCode: egen dev_`x'=mean(tdev_`x')
}

drop tdev*



duplicates drop constCode , force
keep constCode  wealth_*  dev_*
sort constCode
tempfile hh
save `hh'

*****************
*
* Merge up!
*
******************
use `hh', clear


merge 1:1 constCode using `industry_frac'
assert _m == 3
drop _m

sort constCode
merge 1:1 constCode using `religion_and_educ'
assert _m == 3
drop _m


sort constCode
merge 1:1 constCode using `infant'
assert _m == 3
drop _m

sort constCode
merge 1:1 constCode using `religion_and_educ2'
assert _m == 3
drop _m

sort constCode
merge 1:1 constCode using `infant2'
assert _m == 3
drop _m

sort constCode
merge 1:1 constCode using `urban_rural_devs'
assert _m == 3
drop _m


label var wealth_mean "Average Wealth"
label var wealth_sd "Std Dev of Wealth"


* Reshape


sort constCode

save "$zambia/intermediate_data/35_demographics/const_2010_demographics", replace
