set more off

use $zambia_inputs/Demographic/IPUMSCensus2000/IPUMS_Census_2000.dta, clear
renvars ZM00A_*, predrop(6)
gen rural = URBAN == 1 if URBAN!=.
gen age = AGE
gen female = SEX==2 if SEX!=.
gen dev_enrolled = inlist(ENROLL, 1, 2,3) if ENROLL!=. & age >= 5 & age <= 15

recode LBM* LBF* (9=.)

gen past_year_alive_m = LBMHOME +  LBMAWAY
gen past_year_alive_f = LBFHOME + LBFAWAY
gen past_year_dead_m = LBMDEAD
gen past_year_dead_f = LBFDEAD



egen hh_tag = tag(DWNUM HHNUM)

gen dev_protectedwater = inlist(WATSRC, 1,2,3,4,5) if WATSRC !=.
gen dev_eleclight = inlist(LIGHT, 1) if LIGHT!=.
gen dev_thatchroof = ROOF==4 if ROOF!=.
gen dev_mudfloor = FLOOR == 5 if FLOOR!=.

* Assets also in 2010
local assets "RADIO TV FRIDGE PHONE BICYCLE AUTO MOTORCYC PLOUGH DONKEY"

foreach x in  `assets' {
	gen asset_`x' = (`x' == 1) if `x' !=.
}

pca asset_* if hh_tag==1
predict dev_pca_index if hh_tag==1

rename CONST constCode

****************
* Aggregate
****************


* Infant Mortality

	preserve
		keep past_year* constCode rural
		collapse (sum) past_year* (mean) rural, by(constCode)
		gen dev_infant_mortality = (past_year_dead_m + past_year_dead_f) ///
			/(past_year_dead_m + past_year_alive_m + past_year_dead_f + past_year_alive_f)
		keep dev_* constCode rural
		sort constCode
		tempfile infant
		save `infant', replace
	restore

	preserve
		keep past_year* constCode rural
		collapse (sum) past_year*, by(constCode rural)
		gen dev_infant_mortality = (past_year_dead_m + past_year_dead_f) ///
			/(past_year_dead_m + past_year_alive_m + past_year_dead_f + past_year_alive_f)


		keep dev_* constCode rural
		reshape wide dev_*, i(constCode) j(rural)
		renvars *0, postsub("0" "_urban")
		renvars *1, postsub("1" "_rural")
		sort constCode
		tempfile infant2
		save `infant2', replace

	restore


* Development indicators

	preserve
		keep constCode dev_*
		collapse dev_*, by(constCode)
		sort constCode
		tempfile devs_byconst
		save `devs_byconst'

	restore

* By urban-rural
preserve
	keep constCode dev_* rural

	collapse dev_*, by(constCode rural)

	keep dev_* rural constCode
	reshape wide dev_*, i(constCode) j(rural)
	renvars *0, postsub("0" "_urban")
	renvars *1, postsub("1" "_rural")
	sort constCode

	tempfile devs_byconstrural
	save `devs_byconstrural', replace
restore


use `devs_byconst', clear

sort constCode
merge 1:1 constCode using `devs_byconstrural'
assert _m==3
drop _m

sort constCode
merge 1:1 constCode using `infant'
assert _m==3
drop _m

sort constCode
merge 1:1 constCode using `infant2'
assert _m==3
drop _m


decode constCode, gen(const_string_2000)
* One inconsistency
label drop ZM00A_CONST
recode constCode (55=54) (54=55)
renvars dev_* rural, postfix("_2000")

save "$zambia/intermediate_data/35_demographics/const_2000_demographics", replace
