#####################
# Preamble
#####################

import pandas as pd
import os
pd.set_option('mode.chained_assignment','raise')
pd.options.display.notebook_repr_html = False
wd = os.path.join('C://users/Nick/Documents/Eubank')
os.chdir(wd)


#####################
# Get Tower Data, collapse to one obs per tower, project.
#####################

towerData = pd.read_hdf('intermediate_data/20_georeferencing_users/towerLocations.h5', 'towers')

###################
# Get user-tower data - auto uptypes ints!
####################
typeDict = dict(tower = 'str', userCode = 'int64', voiceDummy = 'int8', count = 'int32')
utd = pd.read_csv('intermediate_data/17_user_tower_pairs/userTowerPairs.csv',  dtype = typeDict)

# Column name weird
utd.rename(columns = {utd.columns[0]:'userCode'}, inplace = True)


# Appear ast strings with decimals, blocking converstion to int
# But too long to be a float
utd.tower.value_counts(dropna = False)
utd.tower = utd.tower.str.replace(r'\.000000', '').astype('int64')
utd.tower.value_counts(dropna = False)

###############
# Merge up!
# CGI is an antenna, and many may exist on one tower. 
##############

utd['left'] = 1
towerData['right'] = 2

uTower = pd.merge(utd, towerData[['SITEID', 'right']], left_on = 'tower', right_index = True, how = 'outer')
del utd
# Check merge

def mergeChecker(data):
    print("requires to have created 'left' and 'right' columns with values 1 and 2 respectively")
    print("had side effect! only run once after merge")
    mChecker = data[['left','right']].fillna(0).astype('int8')
    data['m'] = mChecker.left + mChecker.right
    data.drop(['left', 'right'], axis =1, inplace = True )

mergeChecker(uTower)
uTower.m.value_counts()

# Interrogate mis-merges -- Drop for now. 0.4% only in users, 0.003  only in towers
uTower.sort(columns = ['tower'], inplace = True)
uTower.query('m == 1').tower.head(20)
uTower.query('m == 2').tower.head(20)
pd.set_option('precision', 12)




uTower = uTower.query('m == 3')
uTower.drop(['m',  'tower'], axis = 1, inplace = True)


############
# Collapse to SITEID inctead of antenna (cgi)
################
userTypeSiteGroup = uTower.groupby(['userCode', 'voiceDummy', 'SITEID'] )
uTowerLevel = userTypeSiteGroup.sum()
uTowerLevel.reset_index(inplace=True)   
uTowerLevel.dtypes

del uTower
del userTypeSiteGroup

# The count column name has a collision with ocunt function
uTowerLevel.rename(columns = {'count':'counter'}, inplace = True)

for i in ['voiceDummy', 'SITEID', 'counter', 'userCode']:
    uTowerLevel[i] = uTowerLevel[i].astype('int64')
uTowerLevel.dtypes

try:
    os.remove('intermediate_data/20_georeferencing_users/intermediates.h5')
except: print('did not delete intermediates')
############
# SAVE
##########
uTowerLevel.to_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'usersTowers_CollapsedToTower', mode = 'w')
