# -*- coding: utf-8 -*-
from __future__ import division, print_function

# Imports:
import pandas as pd
import louvain
import igraph as ig
import os
import sys
import numpy as np

# Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 50
pd.options.display.max_columns = 8
pd.options.display.width = 90
pd.set_option('mode.chained_assignment','raise')




# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################
# Prelim test. 

# Test for gorupby sort stability
test = pd.DataFrame({'groups': np.random.randint(0,10, size = 100), 'random_vars': np.random.rand(1,100)[0]})
test.sort('random_vars', inplace = True)

def sort_test(x):
    assert_frame_equal(x, x.sort('random_vars'))
    return 1
    
from pandas.util.testing import assert_frame_equal
test.groupby('groups').apply(sort_test)



# Goals:
# Get each users most used tower
# Merge in all towers with intersection theissens.
# Get most used of those neighbors. 


##############
# Get most used tower
############

users = pd.read_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'usersTowers_CollapsedToTower')
users.rename(columns = {'SITEID':'siteid'}, inplace = True)


# Step 1: when I sort by "counter" within each user-voiceDummy pair,
# i'm going to get lots of ties. 
# I want to (a) use the tower most used in other category when ties appear, and
# (b) use a stable random var to break ties. So here I 
# get most used (ties broken by ties) and the re-record most used breaking ties by 
# most used in other category instead of randomly. (If both categoreis have 
# perfect ties for msot used, then yes, it's random). 

    # the ultimate answer to the ultimate question of the universe
np.random.seed(42)
users['stableRandom'] = np.random.randn(len(users))


# Sort by group and counter
users.sort(columns = ['userCode', 'voiceDummy', 'counter', 'stableRandom'], inplace = True, ascending = False)
assert users.index.is_unique

result = users.groupby(by = ['userCode', 'voiceDummy'], as_index = False)[['userCode', 'voiceDummy', 'siteid']].nth(0)
result = result.pivot(index='userCode', columns='voiceDummy', values='siteid')
result.rename(columns = {0:'mostUsed0', 1:'mostUsed1'}, inplace = True)

l0 = len(users)
users = pd.merge(left = users, right = result, left_on = 'userCode', right_index = True, how = 'outer')
assert len(users) == l0
del result

users['mostUsedInOtherType'] = 0 
users.loc[(users.voiceDummy == 0) & (users.siteid == users.mostUsed1), 'mostUsedInOtherType'] = 1
users.loc[(users.voiceDummy == 1) & (users.siteid == users.mostUsed0), 'mostUsedInOtherType'] = 1
users.drop(labels = ['mostUsed1', 'mostUsed0'], axis = 1, inplace = True)



###
# Now get most used again, this tie-breaking by msot used in other category instead of randomly. (If tied in both groups, it's random, 
# Otherwise deterministic. 
#
# Only want voice
####

users = users.query('voiceDummy == 1')
users.drop(labels = ['stableRandom', 'voiceDummy'], axis = 1, inplace = True)
# Childhood phone number
np.random.seed(307774036)
users['stableRandom'] = pd.Series(np.random.randn(len(users)))


# Get most used
users.sort(columns = ['userCode', 'counter','mostUsedInOtherType', 'stableRandom'], ascending = False, inplace = True)
userGroup = users.groupby(['userCode'], group_keys = False, as_index = False)
users = userGroup[['userCode', 'siteid']].nth(0)
users.rename(columns = {'siteid':'most_used_tower'}, inplace = True)

###################
# OK, now get list of neighbor towers
#################

# Now get neighbors
towers = pd.read_csv('intermediate_data/20_georeferencing_users/second_order_thiessen_siteids_and_towers.csv')
towers.rename(columns = {'PRIMARYSITEID':'most_used_tower', 'SECONDARYSITEID':'neighbors'}, inplace = True)
towers.drop(labels = ['XCoord', 'YCoord', 'SITEID'], axis = 1, inplace = True)


# Merge with trackers

users['_left'] = 1    
towers['_right'] = 2

users_with_neighbors = pd.merge(users, towers, on = 'most_used_tower', how = 'outer')

users_with_neighbors[['_left', '_right']] = users_with_neighbors[['_left', '_right']].replace(np.nan, 0)
users_with_neighbors['_m'] =  users_with_neighbors._left + users_with_neighbors._right
users_with_neighbors.drop(labels = ['_left', '_right'], axis = 1, inplace = True)

users_with_neighbors._m.value_counts(dropna = False)        
    # 41 towers with no users, no users without neighbors. 
assert (users_with_neighbors._m == 1).any() == False
users_with_neighbors = users_with_neighbors.query('_m == 3')
users_with_neighbors.drop(labels = ['_m'], axis = 1, inplace = True)
del users
del userGroup



#############
# Now the hard part: get most used tower neighboring globally most used tower
# This gets a little weird because of :
#
#   User Side Issues:
#   (1) People with calls through main_tower but not neighbors, but where main_otwer has a "this tower, no others" thiessen 
#           - These won't merge with call counts, so I have to keep them intentionly.
#            They will be _m==1 entirely. Keep by making "any_merge" var and keep if not. 
#   (2) People who only use one tower, but whose one tower doesn't have a "this tower only" zone. 
#           - These I'll need to deal with later by recoding to thiessen with actual tower in it. But they 
#            are under 2 for now. 
#
#   Tower Side Issues:
#   (3) Thiessen for people where tower has no neighbors
#           -These people would have gotten NaN as neighbor from merge above, so won't merge with counts. 
#            But again, won't merge with anyone, so will be kept if I keep eople with zero merges. 
##########

users_with_neighbors.to_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'users_most_used_voice_and_neighbors')
users_with_neighbors = pd.read_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'users_most_used_voice_and_neighbors')


user_counters = pd.read_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'usersTowers_CollapsedToTower')
user_counters.rename(columns = {'SITEID':'neighbors'}, inplace = True)
user_counters.query('voiceDummy == 1')
user_counters.drop(labels = 'voiceDummy', axis = 1, inplace = True)


assert pd.notnull(user_counters.neighbors).all() 

# Merge
users_with_neighbors['_left'] = 1    
user_counters['_right'] = 2

neighbors_and_counts = pd.merge(users_with_neighbors, user_counters, on = ['userCode','neighbors'], how = 'outer')

neighbors_and_counts[['_left', '_right']] = neighbors_and_counts[['_left', '_right']].replace(np.nan, 0)
neighbors_and_counts['_m'] =  neighbors_and_counts._left + neighbors_and_counts._right
neighbors_and_counts.drop(labels = ['_left', '_right'], axis = 1, inplace = True)
neighbors_and_counts._m.value_counts(dropna = False)        

# So we don't want towers people call that aren't close, so we can drop 2s safely.
neighbors_and_counts = neighbors_and_counts.query('_m != 2')

# Tag if had ANY merges
neighbors_and_counts['temp'] = neighbors_and_counts.groupby('userCode')['_m'].transform(max)
neighbors_and_counts['any_merges'] = neighbors_and_counts.temp == 3
neighbors_and_counts.drop(labels = 'temp', axis = 1, inplace = True)



# The harder case is 1s. We don't want neighboring towers people don't call, 
# BUT we need to keep rows where tower has no neighbors, 
neighbors_and_counts = neighbors_and_counts.query('_m == 3 | any_merges == False')
neighbors_and_counts.drop(labels = ['_m'], axis = 1, inplace = True)


# Now identify Most used
    # seed with year I graduated high school -- GO PATRIOTS!
np.random.seed(2003)
neighbors_and_counts['stableRandom'] = np.random.randn(len(neighbors_and_counts))

neighbors_and_counts.sort(['userCode', 'counter', 'stableRandom'], ascending = False, inplace = True)

codes = neighbors_and_counts.groupby('userCode').nth(0)


# OK, so people with no use of neighbor towers will have all counter missing.  
# SO if counter missing, set 'second tower' to missing. 
codes.rename(columns = {'neighbors':'most_used_neighbor'}, inplace = True)
codes.loc[pd.isnull(codes.counter), 'most_used_neighbor'] = np.nan
codes.drop(labels = ['stableRandom',  'any_merges', 'counter'], axis = 1, inplace = True)




codes.to_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'codes')
codes = pd.read_hdf('intermediate_data/20_georeferencing_users/intermediates.h5', 'codes')

#######
# Identify users with invalid codes
########
# Problems are people who (a) don't use any of neighbors of their most_used tower, but
# (b) their "most_used" tower has no "this-toweronly" thiessen
# The code directly below finds those thiessens, the code two steps down merges in those
# values for the appropriate people. 

# Quick organization. 
thiessens_with_towers = pd.read_csv('intermediate_data/20_georeferencing_users/second_order_thiessen_siteids_and_towers.csv')
thiessens_with_towers.drop(labels = ['XCoord', 'YCoord'], axis = 1, inplace = True)
thiessens_with_towers['has_tower'] = thiessens_with_towers.PRIMARYSITEID == thiessens_with_towers.SITEID
thiessens_with_towers.rename(columns = {'PRIMARYSITEID':'most_used_tower', 'SECONDARYSITEID':'most_used_neighbor'}, inplace = True)

# Drop all the places where the tower has a second-order thiessen for "this tower only"
thiessens_with_towers['missing_neighbor'] = 0
thiessens_with_towers.loc[pd.isnull(thiessens_with_towers.most_used_neighbor), 'missing_neighbor'] = 1
thiessens_with_towers['has_missing'] = thiessens_with_towers.groupby('most_used_tower')['missing_neighbor'].transform(max)
thiessens_with_towers = thiessens_with_towers.query('has_missing == 0')

# KEep only the thiessen with the tower. 
thiessens_with_towers = thiessens_with_towers.query('has_tower == True')
thiessens_with_towers.drop(labels = ['missing_neighbor', 'has_missing', 'has_tower', 'SITEID'], axis = 1, inplace = True)

# The value we're gonna substitute in
absorbing_thiessen = thiessens_with_towers.rename(columns = {'most_used_neighbor':'absorbing_neighbor_code'})

codes.reset_index(inplace = True)
codes_with_absorbing = pd.merge(codes, absorbing_thiessen, how = 'left', on = 'most_used_tower')


def correct_codes(x):
    if pd.isnull(x[0] ) and pd.notnull(x[1]):
        return  x[1] 
    else: return x[0]
codes_with_absorbing['most_used_neighbor2'] = codes_with_absorbing[['most_used_neighbor', 'absorbing_neighbor_code']].apply(correct_codes, axis = 1, raw = True)



codes_with_absorbing.drop(labels = ['most_used_neighbor', 'absorbing_neighbor_code'], axis = 1, inplace = True)
updated_codes = codes_with_absorbing.rename(columns ={'most_used_neighbor2':'most_used_neighbor'})


    # Two also need to be fixed by hand. Tower 3052 gets placed just outside Zambia. 
    # Closest atcual thiessen is 3052 - 3155; same for 3089, clostest of which is 3089-3040.
updated_codes.loc[(updated_codes.most_used_tower == 3052) & pd.isnull(updated_codes.most_used_neighbor), 'most_used_neighbor'] = 3155
updated_codes.loc[(updated_codes.most_used_tower == 3089) & pd.isnull(updated_codes.most_used_neighbor), 'most_used_neighbor'] = 3040


###########
# Make my single number "thiessen codes"
################
## Id for thiessens 2 is going to be siteid of first used * 10000 + siteid of second + 1 
# (since there's asite  zero, need to add one so zero can be null)
updated_codes['temp'] = updated_codes.most_used_neighbor + 1
assert updated_codes.temp.min() == 1
updated_codes.loc[pd.isnull(updated_codes.most_used_neighbor), 'temp'] = 0
updated_codes['thiessen_id_second'] = updated_codes.most_used_tower * 100000 + updated_codes.temp + 9000000000
updated_codes.drop(labels = 'temp', axis = 1, inplace = True)

assert updated_codes.userCode.duplicated().any() == False

updated_codes.rename(columns = {'most_used_tower':'thiessen_id_first'}, inplace = True)
updated_codes.drop(labels = ['most_used_neighbor'], axis = 1, inplace = True)

updated_codes.to_hdf('intermediate_data/10_edgelists_and_graphobjects/masterUsers.h5', 'thiessenCodes')
