# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import os
import sys
nan = np.nan
#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 160
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.options.display.width = 150
pd.set_option('mode.chained_assignment','raise')

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Get GIS, calculate weights
#########################
wards = dict()
for t_order in [ 'second', 'first']:
    df = pd.read_csv('intermediate_data/20_georeferencing_users/thiessens_{}Order_wards.csv'.format(t_order))
    
    # Clean and add second order code

    df.drop(labels = ['XCoord', 'YCoord'], axis = 1, inplace = True)
    df.rename(columns = {'PRIMARYSITEID':'primarySiteID', 'SECONDARYSITEID':'secondarySiteID',
                         'INTERSECTAREA': 't_area', 
                         'WARDCODE': 'wardCode', 
                         'CONSTCODE':'constCode',
                         }, inplace = True)
    
    # Since I want to keep my -99s intact and independent for 
    # this, need an ide. So:
    df.reset_index(inplace = True)
    df.rename(columns = {'index':'temp'}, inplace = True)
    df.temp = df.temp * -1
    df.temp = df.temp + df.wardCode
    df.loc[df.wardCode < 0, 'wardCode'] = df.temp
    df.drop(labels = 'temp', axis = 1, inplace = True)
    # OK, now all the -99 values have unique IDs. 
    
    
    
    if t_order == 'first':

        # Places with no coverage need a primaryStieID of -1
        df.loc[(df.primarySiteID == 0) & (df.secondarySiteID == 0), 'primarySiteID'] = -1

        df.drop(labels = 'secondarySiteID', inplace = True, axis = 1)
        df.rename(columns = {'primarySiteID':'t_id'}, inplace = True)
        
        
        
    if t_order == 'second':
        
        df['no_coverage'] = 0
        df.loc[(df.primarySiteID == 0) & (df.secondarySiteID == 0), 'no_coverage'] = 1
        
        df.secondarySiteID = df.secondarySiteID + 1
        df.loc[pd.isnull(df.secondarySiteID), 'secondarySiteID'] = 0        
        df.secondarySiteID = df.secondarySiteID + df.primarySiteID * 100000 + 9000000000
        df.drop(labels = 'primarySiteID', axis = 1, inplace = True)
        df.rename(columns = {'secondarySiteID':'t_id'}, inplace = True)

        # Places with no coverage need t_ids of negative 1. 
        df.loc[df.no_coverage == 1, 't_id'] = -1
        df.drop(labels = 'no_coverage', inplace = True, axis = 1)
        
        
    # Note this will NOT collapse -99 slivers because those all have unique IDs now. 
    # And since I will eventually drop them (not use in network stats), 
    # that's ok. 

    # Few checks
    # No dups
    assert df[['t_id','wardCode']].duplicated().any() == False
    # All have constCodes
    assert len(df.constCode.value_counts(dropna = False)) == 150
    assert (pd.isnull(df.constCode)).any() == False

    wards[t_order] = df


##############
# OK, now I need to merge in population
# MUST RUN AFTER FOLDER 30!!!!
#############
pop = pd.read_stata('intermediate_data/35_demographics/wards_2010.dta')
pop = pop[['pop_num_total', 'wardCode']]
pop.rename(columns = {'pop_num_total':'ward_pop'}, inplace = True)

wards_pop = dict()
for t_order in ['first', 'second']:
    
    d = pd.merge(wards[t_order], pop, on = 'wardCode', how = 'left')
    d['ward_area' ] = d.groupby('wardCode')['t_area'].transform(sum)
    assert pd.isnull(d.t_area).any() == False    
    
    # Two wards known to be missing -- just not in census! 
    assert pd.isnull(d.query('wardCode != 8024 & wardCode != 3213 & wardCode > 0').ward_pop).any() == False    
    
    d.query('wardCode >=0 & ward_pop != ward_pop')
    
    d['w_density'] = d['ward_pop']  / d['ward_area']
    d.sort(['wardCode'], inplace = True)

    wards_pop[t_order] = d
        
        
############
# Now get constituency average density to fill in gaps
###########
consts = pd.read_stata('intermediate_data/35_demographics/constPopulation2010.dta')
consts.rename(columns = {'population':'const_pop'}, inplace = True) 
        
wards_pop2 = dict()
for t_order in ['second', 'first']:
    d = pd.merge(wards_pop[t_order], consts, on = 'constCode', how = 'left')
    assert pd.isnull(d.query('constCode != 59 & constCode != 61').const_pop).any() == False

    d['const_area'] = d.groupby('constCode')['t_area'].transform(sum)


    ########
    # Now I want both uncovered (by wards) area and uncovered population
    ########

    # Get area without population data
    d['temp'] = np.nan
    d.loc[pd.isnull(d.ward_pop), 'temp'] = d.t_area
    d['const_area_withoutpop']  = d.groupby('constCode').transform(sum)['temp']
    d.const_area_withoutpop = d.const_area_withoutpop.replace(np.nan, 0)

    # Get population missing
        # Sum with pop
    temp = d.query('ward_pop == ward_pop').drop_duplicates('wardCode')[['constCode', 'ward_pop']]
    temp = temp.groupby('constCode').sum()
    temp.rename(columns = {'ward_pop':'accounted_for_pop'}, inplace = True)
    temp.reset_index(inplace = True)

        # Bring back in and difference
    d2 = pd.merge(d, temp, how = 'left', on = 'constCode')
    d2['accounted_for_pop'] = d2.accounted_for_pop.replace(np.nan, 0)

    # 9 consts all empty. 
    assert(len(d2.drop_duplicates('constCode').query('accounted_for_pop == 0')) == 9)

    d2['unaccounted_pop'] = d2.const_pop - d2.accounted_for_pop

    # There are two constituencies -- 4 and 143 -- where there were wards
    # in the census I just couldn't find on maps, so let's assume what I 
    # was able to merge at ward level is right. 
    d2.loc[(d2.constCode == 4) | (d2.constCode == 143), 'unaccounted_pop'] = 0
    d2.loc[(d2.constCode == 4) | (d2.constCode == 143), 'const_area_withoutpop'] = 0


    # 13 have <0  wrds, 
    # plus 80 has a field missing an entry
    # Dropped 59 & 61 since constituency numbers weren't right (wards ok)
    # 

    assert len(d2.query('unaccounted_pop  != 0').drop_duplicates('constCode')) == 15
    
    # Two consts had undependable pops at constituency level
    #  but all wards covered and dealt with at word level. 
    d2.loc[(d2.constCode == 59) | (d2.constCode == 61), 'unaccounted_pop'] = 0
    # Make sure that 
    assert pd.isnull(d2.unaccounted_pop).any() == False

    # So density of unlabeled wards:
    d2['fill_density'] = d2['unaccounted_pop'] / d2['const_area_withoutpop'] 
    d2['fill_density'] = d2.fill_density.replace(np.inf, np.nan)

    # One oddity is const 32, which has an extra ward I was never ablet o merge. 
    # Assign avg density for constiteuncy. 
    avg_32 = d2.query('constCode == 32').mean()['w_density']
    d2.loc[d2.constCode == 32, 'fill_density'] = avg_32

    # 13 constituencies have wards with -99 codes, plus const 32.
    assert len(d2.fill_density.value_counts()) == 14
    

    # Now put in that density where local density missing. 
    assert pd.isnull(d2.t_area).any() == False
    d2['t_density'] = d2['w_density']
    d2.loc[pd.isnull(d2.t_density),'t_density'] = d2.fill_density 
    d2['t_pop'] = d2['t_density'] * d2['t_area']

    # More eyballing
    #
    #d2['has_missing'] = 0
    #d2.loc[d2.wardCode < 0, 'has_missing'] = 1     
    #d2['has_missing'] = d2.groupby('constCode').transform(max)['has_missing']
    #
    ## Verious eyeballing
    #temp = d2.copy()
    #temp['summed_pop'] = d2.groupby('constCode').transform(sum)['t_pop']
    #temp['pre_density'] = d2.groupby('constCode').transform(np.mean)['t_density']
    #temp['post_density'] =temp.groupby('constCode').transform(np.mean)['w_density']
    #consts = temp.drop_duplicates('constCode')
    #consts.pre_density = temp.pre_density * 10000
    #consts.post_density = temp.post_density * 10000
    #
    ## Pop dif should be tiny for all but 143 and 4 (they just have a ward from census that 
    ## didn't merge in, so they have low totals. They werne't affected by these substitions. 
    #consts['pop_dif'] = (consts.summed_pop - consts.const_pop)/consts.const_pop
    #consts.query('has_missing == 1')[['constCode', 'summed_pop', 'const_pop', 'pop_dif', 'pre_density', 'post_density']] 
    #consts.query('pop_dif > 0.05 | pop_dif < -0.05')[['has_missing', 'constCode', 'summed_pop', 'const_pop', 'pop_dif', 'meaned_density', 'avg_w_density']] 
    
        

    wards_pop2[t_order] = d2[['t_id', 'wardCode', 'constCode', 't_area', 't_density']]


########
# Create actual weights
########
for t_order in ['second', 'first']:
    weight = 'weight_' + t_order    
    
    d = wards_pop2[t_order].copy()
    
    d['t_pop'] = d['t_area'] * d['t_density']
    d.drop(labels = ['t_area', 't_density'], axis = 1 , inplace = True)
    
    d['temp'] = d[['t_id', 't_pop']].groupby('t_id').transform(sum)
    assert pd.isnull(d['temp']).any() == False
    d[weight] = d['t_pop'] / d['temp'] 
    assert pd.isnull(d[weight]).any() == False
    d.drop(labels = 'temp', axis = 1, inplace = True)
    
    weight_sum = d.groupby('t_id').sum()[weight]
    assert ((weight_sum >= 0.99) & (weight_sum < 1.01)).all()
    del weight_sum 
        
    d.drop(labels = 't_pop', axis = 1, inplace = True) 
    d.to_hdf('intermediate_data/20_georeferencing_users/weights.h5', 'weights_' + t_order)


