# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import os
import sys

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################

users = pd.read_hdf('intermediate_data/10_edgelists_and_graphobjects/masterUsers.h5', 'thiessenCodes')

weight_dict = dict()
for t_order in ['first', 'second']:
    weights = pd.read_hdf('intermediate_data/20_georeferencing_users/weights.h5', 'weights_'+t_order)

    key = 'thiessen_id_{}'.format(t_order)

    # Merging!
    users['_left'] = 1    
    weights['_right'] = 2
    
    user_weights = pd.merge(users, weights, left_on = key, right_on = 't_id', how = 'outer')

    user_weights[['_left', '_right']] = user_weights[['_left', '_right']].replace(np.nan, 0)
    user_weights['_m'] =  user_weights._left + user_weights._right
    user_weights._m.value_counts(dropna = False)  


    ###########
    # Check merges!
    ############
    # No values of 1 (all users find a thiessen). 
    assert (user_weights._m == 1).any() == False

    # Values of 2 should all be areas with no coverage
    # (t_id = -1), but some exceptions.
    user_weights.query('_m == 2 & t_id != -1').t_id.value_counts()

    # In order = 'first':
    user_weights.query('_m == 2 & t_id != -1').t_id.value_counts()

        # 8 cells without users. All towers with siteid between 3262 and 3331. 
        # Most peri-urban copperbelt where lots of small slivers. 

    # In order = 'second':
    # Also mostly 32 - 33 range for first or second tower. Wonder if those have issues...
    # Seems (for second-order) I have 276 thiessens with no people, 
    # distributed across 118 wards in 44 constituencies. But none are full 
    # ward or constituency errors (i.e. I have people in all wards and constituencies). 
    # vast majority seem to  be siteids between 32 and 33 as eithe first or second
    user_weights.query('_m == 2 & t_id != -1').constCode.value_counts()
        # Majority are consts: 16, 22, 7, 19, 25, 70, 17, 21 -- all but two of these in Copperbelt. 
        # Seem like just honest "no one with that pattern" cases. 
    
    user_weights = user_weights.query('_m == 3')
    assert (user_weights.t_id == -1).any() == False
    

    ########
    # Clean 
    #####
    user_weights.drop(labels = ['_left', '_right', '_m'], axis = 1, inplace = True)
   
    # Drop wrong key from user
    non_key = 'thiessen_id_first' if t_order == 'second' else 'thiessen_id_second'
    #    user_weights.drop(labels = [non_key, 't_id'], axis = 1, inplace = True)

     # Couple cleanliness checks
    assert user_weights.duplicated(['userCode', 'wardCode']).any() == False    

    print('{} users, {} shapes, {} average repeats.'.format(len(users), len(weights), float(len(user_weights)) / len(users)))

    # Sum check
    weight = 'weight_' + t_order
    weight_sum = user_weights[['userCode', weight]].groupby('userCode').sum()
    assert ((weight_sum[weight] > 0.99) & (weight_sum[weight] < 1.01)).all()

    
    weight_dict[t_order] = user_weights

    
############
# Gather
##############   

# Since second order thiessens are subsets of first, should always have people in fewer wards.
# The only exception are the wards with codes below zero, which are undependable. 

######
# Combine wards. 
######

assert weight_dict

drops = ['constCode', 't_id', 'thiessen_id_first', 'thiessen_id_second']
l = weight_dict['first'].query('wardCode > 0').drop(labels = drops, axis = 1)
r = weight_dict['second'].query('wardCode > 0').drop(labels = drops, axis = 1)

assert l is not weight_dict['first']

assert len(l) > len(r)

l['_left'] = 1
r['_right'] = 2

wards = pd.merge(l, r, on = ['userCode', 'wardCode'], how = 'outer')

wards[['_left', '_right']] = wards[['_left', '_right']].replace(np.nan, 0)
wards['_m'] = wards._left + wards._right
wards.drop(labels = ['_left', '_right'], inplace = True, axis = 1)

assert (wards._m != 2).all()
assert wards.duplicated(['userCode', 'wardCode']).any() == False


wards.to_hdf('intermediate_data/20_georeferencing_users/weights.h5', 'user_ward_weights')

##########
# Constituencies
#######
drops = ['wardCode', 't_id', 'thiessen_id_first', 'thiessen_id_second']
l = weight_dict['first'].drop(labels = drops, axis = 1)
r = weight_dict['second'].drop(labels = drops, axis = 1)

l = l.groupby(['userCode', 'constCode']).sum()
l.reset_index(inplace = True)
r = r.groupby(['userCode', 'constCode']).sum()
r.reset_index(inplace = True)

l['_left'] = 1
r['_right'] = 2

consts = pd.merge(l, r, on = ['userCode', 'constCode'], how = 'outer')

consts[['_left', '_right']] = consts[['_left', '_right']].replace(np.nan, 0)
consts['_m'] = consts._left + consts._right
consts.drop(labels = ['_left', '_right'], inplace = True, axis = 1)

assert (consts._m != 2).all()

assert pd.isnull(consts.constCode).any() == False
assert consts.duplicated(['constCode', 'userCode']).any() == False
len(consts.userCode.value_counts())
consts.to_hdf('intermediate_data/20_georeferencing_users/weights.h5', 'user_const_weights')


