# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import igraph as ig
import os
import sys
import louvain

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')


# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################
# Load XY coords of thiessen centrids, and make second-order tid
df = pd.read_csv('intermediate_data/20_georeferencing_users/second_order_thiessen_siteidsonly.csv')


df.rename(columns = {'PRIMARYSITEID':'primarySiteID', 'SECONDARYSITEID':'secondarySiteID'
                         }, inplace = True)

df.secondarySiteID = df.secondarySiteID + 1
df.secondarySiteID.replace(np.nan, 0, inplace = True)
df.secondarySiteID = df.secondarySiteID + df.primarySiteID * 100000 + 9000000000
df.drop(labels = 'primarySiteID', axis = 1, inplace = True)
assert df[['secondarySiteID']].duplicated().any() == False



# Merge with users
users = pd.read_hdf('intermediate_data/10_edgelists_and_graphobjects/masterUsers.h5', 'thiessenCodes')
users.drop(labels = 'thiessen_id_first', inplace = True, axis = 1)

users2 = pd.merge(users, df, how = 'left', left_on = 'thiessen_id_second', right_on = 'secondarySiteID')
assert len(users) == len(users2)
users2 = users2[['userCode', 'XCoord', 'YCoord', 'thiessen_id_second']]

users2.to_hdf('intermediate_data/20_georeferencing_users/user_thiessen_centroids.h5', 'users')
