# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import igraph as ig
import os
import sys

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')


# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################
pairs = pd.read_hdf('intermediate_data/25_spatial_calling_patterns/pairFiles.h5', 'pairs')

gps = pd.read_hdf('intermediate_data/20_georeferencing_users/user_thiessen_centroids.h5', 'users')
gps = gps.drop(labels = 'thiessen_id_second', axis = 1)
gps.userCode = gps.userCode.astype('int32')
gps = gps.set_index('userCode')
gps = gps.rename(columns = {'XCoord':'x', 'YCoord':'y'})


# Can't merge in GIS directly due to memory limits, so first just thin pairs.
gps_users = gps[[]]
pairs = pd.merge(pairs, gps_users, left_index = True, right_index = True, how = 'inner')
pairs = pd.merge(pairs, gps_users, left_on = 'userCodeB', right_index= True, how = 'inner')

# Now merge
pairs_w_gis = pd.merge(pairs, gps, left_index = True, right_index = True, how = 'inner')
pairs_w_gis.rename(columns = {'x':'x_a', 'y':'y_a'}, inplace = True)

pairs_w_gis = pd.merge(pairs_w_gis, gps, left_on = 'userCodeB', right_index = True, how = 'inner')
pairs_w_gis.rename(columns = {'x':'x_b', 'y':'y_b'}, inplace = True)

assert (pairs_w_gis.x_a.notnull()).all() == True
assert (pairs_w_gis.x_b.notnull()).all() == True

a = pairs_w_gis.index.nunique()
b = pairs_w_gis.userCodeB.nunique()
assert b > 3000000 and b < 4000000 and a>3000000 and b < 4000000


pairs_w_gis.to_hdf('intermediate_data/25_spatial_calling_patterns/pairFiles.h5', 'pairs_with_gis')
