# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import igraph as ig
import os
import sys
import louvain

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')

import time
# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)
pd.computation.expressions.set_use_numexpr(False)
#########################
# Body
#########################


def Nscore(x):
    # Exepcts membership vector
    df = pd.DataFrame({'communities':x})
    df2 = df.groupby('communities').size()
    df2 = df2 / len(df)
    df2 = np.square(df2)
    print('nscore done')
    sys.stdout.flush()
    return df2.sum()


def getSignificance(x, g):
    # Excepts membership vector
    zPart = ig.VertexClustering(graph = g, membership = x.tolist())
    significance = louvain.quality(graph = g, partition = zPart, method = 'Significance')
    print('significance done')
    sys.stdout.flush()
    return significance

def getStats(x,g):
    global iter_counter
    
    t0 = time.clock()
    result = pd.Series({'significance':getSignificance(x,g), 'nscore': Nscore(x)})
    t1 = time.clock()
    print('iteration: {} of 28 for graph {}, took {} minutes'.format(iter_counter, i, (t1-t0)/60))
    sys.stdout.flush()

    iter_counter += 1 

    return result



stats = dict()
for i in ['wd7', 'wd3', 'cut3', 'cut7']:
    graph = ig.Graph.Read('intermediate_data/10_edgelists_and_graphobjects/zGraph_{}.pkl'.format(i), format = 'pickle')
    comms = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', i)
    
    

    comms = comms.drop(labels = 'userCode', axis = 1 )    
    comms = comms.set_index('vertexID')
    comms = comms.sort_index()
    
    def func(x):
        return getStats(x,graph)

    iter_counter = 0        
    stat = comms.apply(func, axis = 0)


    # Reorganize
    stat = stat.T
    stat.reset_index(inplace = True)
    stat.rename(columns = {'index':'resolution'}, inplace = True)
    stat['resolution'] = stat.resolution.str.replace('comm_', "").astype('float')
    stat['graph'] = i
    stat['ln_resolution'] = np.log(stat.resolution)

    stat.to_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/{}'.format(i))

    stats[i] = stat

aggregated_stats = pd.concat(stats)
aggregated_stats = aggregated_stats.reset_index()
aggregated_stats['ln_resolution'] = np.log(aggregated_stats.resolution)
aggregated_stats = aggregated_stats.rename(columns = {'level_0':'graph', 'level_1':'iteration'})

aggregated_stats.to_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/aggregated')



