# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import igraph as ig
import os
import sys
import louvain
import matplotlib.pyplot as plt

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################



stats = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/aggregated')

max_values = pd.DataFrame({'graph':['cut3', 'cut7', 'wd3','wd7'], 'max_res':np.nan, 'max_significance':np.nan})
max_values = max_values.set_index('graph')
# plot

for i in ['cut3', 'cut7', 'wd3', 'wd7']:
    
    stat = stats.query('graph == "{}"'.format(i))
    stat = stat.set_index('ln_resolution')
    stat.index.name = r'Logged Resolution Parameter $\gamma$'
    stat.rename(columns = {'significance':'Significance'}, inplace = True)
    
    
    plt.clf()
    fig = plt.figure()
    ax = plt.gca()
    
    # Get max
    max_sig = stat.Significance.max()
    max_sig_res = stat[stat.Significance == stat.Significance.max()].index.values[0]
    max_values.loc[i]['max_res'] = max_sig_res 
    max_values.loc[i]['max_significance'] = max_sig 


    stat[['Significance']].plot(title = 'Significance and Resolution Parameter', ax = ax, legend = False, color = 'black').invert_xaxis()
    plt.axvline(x=max_sig_res, linewidth=2, color='red', linestyle = '--')
    plt.text(max_sig_res+ 0.4, max_sig + 5e7 ,r'$\gamma* = {}$'.format(np.exp(max_sig_res)), fontsize = 18)
    ax.set_ylim(top = max_sig+1e8)
    ax.set_ylabel('Significance')
    
    plt.savefig('dropbox/zambia_papers/results/significance_{}.png'.format(i), alpha=True, dpi=600)



max_values.to_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/max_values')
max_values.to_stata('intermediate_data/30_communities/resolution_statistical_significance.dta')
######
# Add sizes
######
#all_cpm = pd.read_hdf('intermediate_data/pd/cpms.h5', 'cpms')
#all_cpm = all_cpm.drop(labels = ['vertexID', 'userCode'], axis=1)
#resolutions = all_cpm.columns.tolist()
#CPMstats = CPMstats.reset_index()
#CPMstats = CPMstats.set_index('resolution')
#CPMstats['avg_size'] = np.nan
#CPMstats = CPMstats.drop(labels = 'Logged Resolution Parameter $\gamma$', axis=1)
#
#for i in resolutions:
#
#    resolution_as_number = float(i.replace('comm_0', '0.'))*2
#    
#    if resolution_as_number <=1:
#        
#        # sizes = all_cpm[['userCode', i]].groupby(by=i)[i].transform(len)
#        sizes = all_cpm[[i]].groupby(by=i).size()
#        total = sizes.sum().astype('float')
#        sizes = sizes**2
#        mean_size = np.divide(sizes, total)
#        mean_size = mean_size.sum()
#    
#    
#        print('added {} at resolution {}'.format(i, resolution_as_number))
#        sys.stdout.flush()
#        CPMstats['avg_size'].loc[resolution_as_number] = mean_size
#
#
#
#CPMstats.to_stata('intermediate_data/stata/significance_scores.dta')
#
## Peak at 1.500000e-04, but due to anatella resolution
## parameter scaling issue, named '0.000075'
#
#f = pd.HDFStore('intermediate_data/pd/masterUsers.h5')
#f['bestCPM'] = f['networkStats/Anatella_CPM_0000075']
#
#f['bestCPM'].to_stata('intermediate_data/stata/cpm_communities.dta')
#
#
#
#f.close()
