clear
set more off

use $zambia_inputs/afrobarometer/afro_2009_withIdentifiers.dta, clear


***********
* Recode and rename basic controls
************
	gen basic_age = Q1 if Q1!=998 & Q1!=999
	gen basic_female = Q101==2
	gen basic_listenToradio = Q12A!=0 if Q12A!=9 & Q12A!=-1
	rename Q89 basic_educ
	gen basic_ownRadio = Q92A == 1 if Q92A!=-1
	gen basic_ownTV = Q92B == 1 if Q92B!=-1
	gen basic_ownMotorVehicle = Q92C == 1 if Q92C!=-1
	pca basic_own*
	predict basic_pcaWealthIndex, score
	foreach x in A B C D E {
		gen basic_goneWithout`x' = (Q8`x' == 0) if Q8`x' !=-1 & Q8C!=9
	}
	rename basic_goneWithoutA basic_goneWithoutFood
	rename basic_goneWithoutB basic_goneWithoutWater
	rename basic_goneWithoutC basic_goneWithoutMedical
	rename basic_goneWithoutD basic_goneWithoutCookFuel
	rename basic_goneWithoutE basic_goneWithoutCashIncome

	pca basic_goneWithout*
	predict basic_deprevationIndex, score

	rename Q97 basic_party

	foreach x in A B C {
		gen basic_insecurity`x' = (Q9`x'==0) if Q9`x'!=-1 & Q9`x' !=9
	}
	rename basic_insecurityA basic_insecur_fearCrimeHome
	rename basic_insecurityB basic_insecur_robbedHome
	rename basic_insecurityC basic_insecur_physicAttack
	pca basic_insecur*
	predict basic_insecurityIndex, score

	gen basic_urban = urbrur==1 if urbrur!=.


	gen basic_educPrimaryComplete= basic_educ >= 3 if basic_educ >= 0 & basic_educ!=.


*************
* Collective Action Questions
*************
gen CA_votedLastElection = Q23D == 1
gen CA_activeMember_religiousGroup	= (Q22A == 2|Q22A == 3) if Q22A!=-1 & Q22A!=9
gen CA_activeMember_communityGroup = (Q22B ==2 | Q22B == 3) if Q22B!=-1 & Q22B!=9
gen CA_have_attendedDemon = (Q23C == 3|Q23C == 4) if Q23C!=-1 & Q23C!=9
gen CA_haveOrWould_attendDemon = (Q23C == 1| Q23C == 3|Q23C == 4) if Q23C!=-1 & Q23C!=9

gen CA_have_joinOthers = (Q23B == 3|Q23B == 4) if Q23B!=-1 & Q23B!=9
gen CA_haveOrWould_joinOthers = (Q23B == 2|Q23B == 3|Q23B == 4) if Q23B!=-1 & Q23B!=9

gen CA_lc_likelyOrganToMakeListen = Q24A if Q24A!=-1 & Q24A!=9
gen CA_mp_likelyOrganToMakeListen = Q24B if Q24B!=-1 & Q24B!=9

gen CA_lc_everContacted = Q25A if Q25A!=-1 & Q25A!=9
	label values CA_lc_everContacted LABN

gen CA_mp_everContacted = Q25B if Q25B!=-1 & Q25B!=9
	label values CA_mp_everContacted LABN

gen CA_placebo_GovAgcy_everContacted = Q25C if Q25C!=-1 & Q25C!=9
	label values CA_placebo_GovAgcy_everContacted LABN

gen CA_religLead_everContacted = Q27A if Q27A!=-1 & Q27A!=9
	label values CA_religLead_everContacted LABN

gen CA_tradLead_everContacted = Q27B if Q27B!=-1 & Q27B!=9
	label values CA_tradLead_everContacted LABN

gen CA_informalLead_everContacted = Q27C if Q27C!=-1 & Q27C!=9
		label values CA_informalLead_everContacted LABN

gen CA_formalLead_contactWithGroup = Q26A == 2 if Q26A == 1|Q26A==2
gen CA_informalLead_contactWithGroup = Q28A == 2 if Q28A == 1|Q28A==2


************
* Make knowledge index!
************
	* National

	gen DK_mp_name = (Q41A2 == 9) if Q41A2 !=. & Q41A2 !=-1
	gen DK_mp_timeSpentInConst = ( Q53B==9) if Q53B !=. & Q53B !=-1
	gen DK_mp_howMuchDoesListen = (Q54A == 9) if Q54A!=. & Q54A!=-1
	gen DK_mp_overallPerformance = (Q70B == 9) if Q70B!=. & Q70B!=-1

	foreach x in A B C D E F G H I J K L M N O P {
		gen DK_natGov_handlingIssue`x' = (Q57`x' == 9) if Q57`x' !=. & Q57`x'!=-1
	}


	egen PolKnowIndex_mp_allQuestions = rowmean(DK_mp* DK_natGov*)
	replace PolKnowIndex_mp_allQuestions = 1-PolKnowIndex_mp_allQuestions
	egen PolKnowIndex_mp_indivSpecificQs = rowmean(DK_mp*)
	replace PolKnowIndex_mp_indivSpecificQs = 1-PolKnowIndex_mp_indivSpecificQs
	label var PolKnowIndex_mp_allQuestions "National Political Knowledge, All Q"
	label var PolKnowIndex_mp_indivSpecificQs "National Political Knowledge, Indiv Q"

	* Local
	gen DK_lc_listen = (Q54B == 9 ) if Q54B!=. & Q54B!=-1
	gen DK_lc_overallPerformance = (Q70C == 9) if Q70C!=. & Q70C!=-1


	foreach x in A B C D E F  {
		gen DK_localGov_handlingIssue`x' = (Q59`x' == 9) if Q59`x' !=. & Q59`x'!=-1
		gen DK_localGov_otherHowWell`x' = (Q60`x' == 9) if Q60`x'!=. & Q60`x'!=-1
	}

	foreach x in A B C D {
		gen DK_lc_councilorQuals`x' = (Q63`x' == 9) if Q63`x' !=. & Q63`x'!=-1
	}

	egen PolKnowIndex_lc_allQuestions =rowmean(DK_lc* DK_localGov*)
	replace PolKnowIndex_lc_allQuestions = 1-PolKnowIndex_lc_allQuestions
	label var PolKnowIndex_lc_allQuestions "Local Council Political Knowledge, All Q"

	egen PolKnowIndex_lc_indivSpecificQs = rowmean(DK_lc*)
	replace PolKnowIndex_lc_indivSpecificQs = 1-PolKnowIndex_lc_indivSpecificQs
	label var PolKnowIndex_lc_indivSpecificQs "Local Council Political Knowledge, Indiv Q"


	* Knowlege Placebos
	gen DK_natPlacebo_ministerOfFinance = (Q41B2 == 9) if Q41B2!=. & Q41B2!=-1


gen basic_age2 = basic_age^2
gen basic_primaryEduc = (basic_educ >3 &  basic_educ <5)
	label var basic_primaryEduc "Primary Education"
gen basic_secondaryEduc = basic_educ > =5
	label var basic_secondaryEduc "Secondary Education"

label var basic_female "Female"
label var basic_age "Age"
label var basic_age2 "Age Squared"
label var basic_pcaWealthIndex "Asset Wealth Index"


*******
* Corruption Perceptions
*********

keep EANUMB eanumb region district const basic_* CA_*  DK_* region  	PolKn*
save $zambia/intermediate_data/110_afrobarometer/afrobarometer2009, replace



* Gather knowledge questions for "don't know"
	* MP:
		* Name: 41A1
		* Placebo: Minister of Finance: 41B1

	* Collective Action:
		* Local Govt: Join Together: Q62B / Q24A
		* MP: Join together: Q24B
		* When contacted leaders: About personal or community?: Q26B; Go with group or alone: Q26a

	* Procedure questions?
		* Is it following: Q60

	* Trust and Corruption (with haven't heard enough option:)
		* Trust: Q49*
		* Corruption: Q49*; personal experience Q51 as control.

	* Performance:
		* MP: Q57
		* Local: Q58

	* MP Visits: Q53B
