clear
set more off

*************
* GIS
**************
insheet using $zambia_inputs/GIS/Zambia_ConstituenciesAndWards_2006to2010_AttributeTable.csv, comma clear
drop fid_ objectid wardnum

rename wardcode wardCode
rename wardname wardName

rename constcode constCode
rename constname constName

rename distname distName

replace wardName = proper(wardName)


drop if  wardName == "Missing" | wardName == "Map Labels Unclear"


keep distName constName constCode wardName wardCode 
sort  constCode wardName 
tempfile giscodes
save `giscodes', replace


**************
* Wards from Survey Agency
***************
local i = 0
foreach x in "Central" ///
			"copperbelt" ///
			"Eastern" ///
			"Luapula"  ///
			"Northwestern" ///
			"Northern" ///
			"Southern" ///
			"Western" ///
			"Lusaka" {
	import excel using "$zambia_inputs/afrobarometer/afro2009_wardKey/`x'.xls", clear firstrow
	
	
	
	capture drop if GISEAID ==.
	capture drop if GISEAID == ""
	capture destring GISEAID, ignore(",") replace
	display "`x'"
	bysort GISEAID wcode: drop if _n > 1
	
	
	
	foreach x in province district constituency ward region const {
		local l = lower("`x'")
		local p = proper("`x'")
		local u = upper("`x'")
		capture rename `u' `l'
		capture rename `p' `l'
	}
	
	capture rename CONTITUENCY constituency
	capture rename const constituency
	capture rename Consituency constituency

	
	keep province district constituency ward  GISEAID
	
	tempfile t`i'
	save `t`i'', replace
	
	local i = `i'+1
	}

	
use `t0', clear

local top = `i' -1
forvalues x = 1/`top'{
	merge 1:1 GISEAID using `t`x''
	assert _m ~=3
	drop _m
}
sort GISEAID
tempfile codes
save `codes'



use $zambia/intermediate_data/110_afrobarometer/afrobarometer2009, clear
destring eanumb, replace
rename eanumb GISEAID
sort GISEAID 
merge m:1 GISEAID using `codes'
tab _m

	* 2 sites, 16 people I can't match. Both in Lusaka district. 
	* only affects wards, so keep anyway!
	
keep if _m == 3 | _m==1
drop _m	

******************
* Now GIS merge
*****************

gen constCode = .
rename const constName
replace constCode = 37 if constName == "CHADIZA"
replace constCode = 40 if constName == "CHAMA SOUTH"
replace constCode = 103 if constName == "CHAVUMA"
replace constCode = 1 if constName == "CHISAMBA"
replace constCode = 2 if constName == "KATUBA"
replace constCode = 65 if constName == "CHIENGI"
replace constCode = 15 if constName == "CHILILABOMBWE"
replace constCode = 16 if constName == "CHINGOLA"
replace constCode = 17 if constName == "NCHANGA"
replace constCode = 83 if constName == "CHINSALI"
replace constCode = 44 if constName == "LUANGENI"
replace constCode = 115 if constName == "CHOMA"
replace constCode = 117 if constName == "PEMBA"
replace constCode = 73 if constName == "CHONGWE"
replace constCode = 4 if constName == "BWACHA"
replace constCode = 72 if constName == "CHILANGA"
replace constCode = 70 if constName == "KAFUE"
replace constCode = 136 if constName == "SIKONGO"
replace constCode = 119 if constName == "DUNDUMWEZI"
replace constCode = 18 if constName == "KALULUSHI"
replace constCode = 137 if constName == "KAOMA CENTRAL"
replace constCode = 139 if constName == "MANGANGO"
replace constCode = 6 if constName == "KAPIRI MPOSHI"
replace constCode = 90 if constName == "KASAMA"
replace constCode = 106 if constName == "KASEMPA"
replace constCode = 46 if constName == "MKAIKA"
replace constCode = 121 if constName == "KATOMBOLA"
replace constCode = 19 if constName == "CHIMWEMWE"
replace constCode = 20 if constName == "KAMFINSA"
replace constCode = 21 if constName == "KWACHA"
replace constCode = 22 if constName == "NKANA"
replace constCode = 23 if constName == "WUSAKILE"
replace constCode = 123 if constName == "LIVINGSTONE"
replace constCode = 24 if constName == "LUANSHYA"
replace constCode = 25 if constName == "ROAN"
replace constCode = 48 if constName == "CHASEFU"
replace constCode = 50 if constName == "LUNDAZI"
replace constCode = 75 if constName == "CHAWAMA"
replace constCode = 76 if constName == "KABWATA"
replace constCode = 77 if constName == "KANYAMA"
replace constCode = 78 if constName == "LUSAKA CENTRAL"
replace constCode = 79 if constName == "MANDEVU"
replace constCode = 80 if constName == "MATERO"
replace constCode = 81 if constName == "MUNALI"
replace constCode = 94 if constName == "LUPOSOSHI"
replace constCode = 59 if constName == "BAHATI"
replace constCode = 29 if constName == "KAFULAFUTA"
replace constCode = 125 if constName == "MAGOYE"
replace constCode = 126 if constName == "MAZABUKA"
replace constCode = 142 if constName == "LUENA"
replace constCode = 143 if constName == "MONGU"
replace constCode = 127 if constName == "BWEENGWA"
replace constCode = 32 if constName == "MPONGWE"
replace constCode = 96 if constName == "MPULUNGU"
replace constCode = 27 if constName == "KANTANSHI"
replace constCode = 28 if constName == "MUFULIRA"
replace constCode = 11 if constName == "NANGOMA"
replace constCode = 92 if constName == "MALOLE"
replace constCode = 87 if constName == "NAKONDE"
replace constCode = 131 if constName == "NAMWALA"
replace constCode = 66 if constName == "NCHELENGE"
replace constCode = 34 if constName == "CHIFUBU"
replace constCode = 35 if constName == "KABUSHI"
replace constCode = 52 if constName == "NYIMBA"
replace constCode = 55 if constName == "PETAUKE"
replace constCode = 68 if constName == "CHIFUNABULI"
replace constCode = 145 if constName == "NALOLO"
replace constCode = 147 if constName == "SINJEMBELA"
replace constCode = 133 if constName == "SINAZONGWE"
replace constCode = 110 if constName == "SOLWEZI CENTRAL"
replace constCode = 112 if constName == "SOLWEZI WEST"
replace constCode = 42 if constName == "CHIPATA CENTRAL"
replace constCode = 5 if constName == "KABWE"
replace constCode = 91 if constName == "LUKASHA"
replace constCode = 97 if constName == "SENGA"
replace constCode = 100 if constName == "MPIKA CENTRAL"
replace constCode = 9 if constName == "MWEMBESHI"
replace constCode = 109 if constName == "MWINILUNGA WEST"
	* Mwinilunga split into Ikelenge in 2011. This is Ikelenge based on ward name. 

replace constCode = 33 if constName == "BWANAMUKUBWA"
replace constCode = 36 if constName == "NDOLA CENTRAL"
replace constCode = 85 if constName == "ISOKA EAST"
replace constCode = 86 if constName == "ISOKA WEST"


* The district and the wardname both put this in Mansa constituency. 
replace constCode = 61 if constName == "CHEMBE"
replace constName = "MANSA" if constCode == 61

assert constCode != .

* Now wards
replace ward = proper(ward)
replace ward = trim(ward)
replace ward = "Mushishi" if ward == "Muswishi" & constCode ==1
replace ward = "Kavid Ramushu" if ward == "David Ramushu" & constCode ==5
replace ward = "Nakasaka" if ward == "Nakasa" & constCode ==11
replace ward = "Chitimukulu" if ward == "Chiti Mukulu" & constCode ==15
replace ward = "Chisupa" if ward == "Remmy Chisupa" & constCode ==18
replace ward = "Levi Chito" if ward == "Levi Chiko *" & constCode ==24
replace ward = "Mpatamatu" if ward == "Mpatamantu" & constCode ==25
replace ward = "-99" if ward == "Kanjala" & constCode ==42
replace ward = "-99" if ward == "Msanga" & constCode ==42
replace ward = "-99" if ward == "Khova" & constCode ==44
replace ward = "Merged Wards" if ward == "Msuzi" & constCode ==50
replace ward = "Ntandabale" if ward == "Ntandabala" & constCode ==73
replace ward = "Harry Mwaanga Nkumbula" if ward == "Harry Mwanga Nkumbula" & constCode ==77
replace ward = "Independence" if ward == "Idependence" & constCode ==78
replace ward = "Justine Kabwe" if ward == "Justin Kabwe" & constCode ==79
replace ward = "Raphael Chota" if ward == "Raphael" & constCode ==79
replace ward = "Chibulula" if ward == "Chibuluma" & constCode ==96
replace ward = "Chimbili" if ward == "Chibili" & constCode ==97
replace ward = "Chavuma Central" if ward == "Chavuma" & constCode ==103
replace ward = "-99" if ward == "Kimasala" & constCode ==110
replace ward = "-99" if ward == "Mumena" & constCode ==112
replace ward = "Merged Wards" if ward == "Mabula" & constCode ==115
replace ward = "Mwanachingwala" if ward == "Mwachigwala" & constCode ==125
replace ward = "Namwala Central" if ward == "Namwala Central" & constCode ==131
replace ward = "Nangombe" if ward == "Nang'Ombe" & constCode ==133
replace ward = "Merged Wards" if ward == "Mulambwa" & constCode ==143
replace ward = "Kapiri Central" if ward == "Kapiri-Mposhi" & constCode == 6
replace ward = "-99" if ward == "Kafue" & constCode == 20
replace ward = "Sasamwenjue" if ward == "Nsansamwenje" & constCode == 86
replace ward = "-99" if ward == "Mbeta" & constCode == 147


rename ward wardName
rename EANUMB_AB site_num
sort constCode wardName

* get wardCodes
merge m:1 constCode wardName using `giscodes'

* Few I can't pin down, and many wards with no data. 
* Drop wards with no data. 
drop if _m == 2
drop _m



save $zambia/intermediate_data/110_afrobarometer/afrobarometer2009_withConstVars, replace



/*



