# -*- coding: utf-8 -*-
"""
Created on Fri Sep 18 20:33:15 2015

@author: Nick
"""

##
import pandas as pd
import numpy as np
import os
import sys

pd.options.display.max_rows = 200
pd.options.display.max_columns = 90
pd.set_option('display.width', 150)
pd.set_option('io.hdf.default_format', 'table')
pd.set_option('mode.chained_assignment','raise')

##
wd = r'/volumes/zambia'
os.chdir(wd)


import seaborn as sns
sns.set(color_codes=True)
import matplotlib.pyplot as plt



###################
# Gather Parts
####################

# Guide to most sig resolutions
max_values = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/max_values')


# Now make geo-referenced


# Communities
comm_vect = dict()

names = {'cut3':'All-Days, >2', 'cut7':'All-Days, >6', 'wd3':'Weekend-Only, >2', 'wd7':'Weekend-Only, >6'}

for graph in ['cut3', 'cut7', 'wd3', 'wd7']:

    target_res = round(np.exp(max_values.loc[graph]['max_res']), 8)
    target_res = 'comm_{:0.8f}'.format(target_res)

    comms = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', graph)
    comms = comms[['userCode',target_res]]
    comms[names[graph]] = comms.groupby([target_res]).transform(len)
    comm_vect[graph] = comms[names[graph]]

#####
# Summary STats
#####
from tabulate import tabulate

comm_stats = pd.DataFrame({'mean':[0]*4, 'median':[0]*4, 'max':[0]*4},
                           index=['All-Days, >2', 'All-Days, >6', 'Weekend-Only, >2', 'Weekend-Only, >6'])

comm_stats = comm_stats[['mean','median','max']]
for graph in ['cut3', 'cut7', 'wd3', 'wd7']:
    comm_stats.loc[names[graph],'mean'] = comm_vect[graph].mean()
    comm_stats.loc[names[graph],'median'] = comm_vect[graph].median()
    comm_stats.loc[names[graph],'max'] = comm_vect[graph].max()


headers = ['Mean Size', 'Median Size', 'Largest Size']
table = tabulate(comm_stats, headers, tablefmt="latex_booktabs", floatfmt=",.0f")
table

with open("results/community_summary_stats.tex", "w") as outfile:
    outfile.writelines(table)


####
# Histograms
###
plt.clf()

f, axes = plt.subplots(2, 2, figsize=(7, 7))

a = axes[0,0]
sns.distplot(comm_vect['cut3'], kde=False, rug=False, ax=a, norm_hist=True)
a.set_title(names['cut3'])
a.set_xlabel('Size of Communities')

a = axes[0,1]
sns.distplot(comm_vect['cut7'], kde=False, rug=False, ax=a, norm_hist=True)
a.set_title(names['cut7'])
a.set_xlabel('Size of Communities')

a = axes[1,0]
sns.distplot(comm_vect['wd3'], kde=False, rug=False, ax=a, norm_hist=True)
a.set_title(names['wd3'])
a.set_xlabel('Size of Communities')

a = axes[1,1]
sns.distplot(comm_vect['wd7'], kde=False, rug=False, ax=a, norm_hist=True)
a.set_title(names['wd7'])
a.set_xlabel('Size of Communities')

#f.suptitle('Population Weighted Community Sizes')
plt.tight_layout()


location = 'results/community_histograms.png'
plt.savefig(location, alpha=True)
