# -*- coding: utf-8 -*-

# Imports:
import shapely as sp
import pandas as pd
import shapely.geometry as spg
import shapely.speedups as sps
import pyproj
import fiona
import os
sps.available
sps.enable()
import descartes as dt
from matplotlib import pyplot as plt
import matplotlib.colors as mcolors
import matplotlib as mpl

# Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 40

# WD
wd = r'/volumes/zambia'
os.chdir(wd)
import numpy as np
inputs = r'/volumes/zambia/third_party_data'


#################
#################
# NOW FOR MAPPING!
# So now I have users and locations in cpm, and community sizes in comms.
#################
#################



# Setup
shapes = fiona.open(inputs + r'/gis/Zambia_ConstituenciesAndWards_2006to2010/Zambia_Country_2006to2010_UTM35S.shp')
provs = spg.MultiPolygon([spg.shape(prov['geometry']) for prov in shapes])
shapes.close()

# Define plotting
def plot_community(comm_index, ax, include_title = True, max_density = 1E-9, cmin = 10):
    cid = communities_by_size.index[comm_index]
    df = users[users[target_res]==cid]

    # Setup image
    frame_range = [ [-100000, 1300000], [8000000, 9100000]]

    ax.set_xlim(frame_range[0][0], frame_range[0][1])
    ax.set_ylim(frame_range[1][0], frame_range[1][1])
    ax.set_aspect(1)

    # Put in provinces
    for i in provs:
        ax.add_patch(dt.PolygonPatch(i, fc = 'None', ec = 'black', alpha = 0.8))


    # Add cities
    cities = [
        ['Lusaka', (638500,8295900)],
        ['Livingstone', (381200, 8025600)],
        ['Ndola', (676500, 8563700)]
        ]

    #         ['Kitwe', (632200, 8583800)], ['Chingola', (596200,8612700)]


    for city in cities:
        ax.annotate(city[0], xy = (city[1][0] + 30000, city[1][1] ), color = 'black', size = 'small', alpha = 1)
        plt.plot(city[1][0], city[1][1], color = 'black', marker = '.', markersize=4.0, alpha = 0.5)

    #map_norm = mcolors.LogNorm(vmin = 1E-20, vmax = max_density)
    map_norm = mcolors.Normalize(vmin = 0, vmax = max_density)
    # Communities
    H = ax.hist2d(df.XCoord.values, df.YCoord.values, bins = 20,
               cmap = 'Reds', range = frame_range, normed = True, norm = map_norm, cmin = cmin)


    ax.set_xticks([])
    ax.set_yticks([])
    ax.set_frame_on(False)
    ax.set_axis_off()
    #cb = fig.colorbar(plt.get_cmap('YlOrRd'), ax = ax)

    if include_title:
        title = 'Community Size: {:,} users'.format(communities_by_size.iloc[comm_index])
        ax.set_title(title, fontsize=10)
        #ax.text(0.5, 0.05, title,fontsize=10,ha='center')

    return H[3]

# Make a bunch for me to look at:

#for i in range(100):
#    plt.clf()
#    fig = plt.figure()
#    ax = fig.add_subplot(1,1,1)
#    plot_community(i,ax)
#    plt.savefig('results/community_maps/community_dist_{}.png'.format(i), alpha=True, dpi=600)

####
# Make a contact sheet
####


loop = dict()

loop['cut3'] = {'min':1E-13, 'max':5E-11}
loop['cut7'] = {'min':1E-12, 'max':5E-11}
loop['wd3'] = {'min':1E-11, 'max':5E-11}
loop['wd7'] = {'min':1E-12, 'max':5E-11}


for graph in ['cut3', 'cut7', 'wd3','wd7']:


    max_values = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/max_values')
    target_res = round(np.exp(max_values.loc[graph]['max_res']), 8)
    target_res = 'comm_{:0.8f}'.format(target_res)

    cpm = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', graph)
    cpm = cpm[['userCode',target_res]]
    communities_by_size = cpm.groupby([target_res]).size()
    communities_by_size = communities_by_size.sort_values(ascending=False)

    # Get GIS coordinates
    user_gis = pd.read_hdf('intermediate_data/20_georeferencing_users/user_thiessen_centroids.h5', 'users')
    users = pd.merge(user_gis, cpm, how = 'left', on = 'userCode')
    users = users[['userCode', 'XCoord', 'YCoord', target_res]]



    import numpy.random

    across = 2
    down = 4
    total = across * down

    # seed with Lexi's b-day
    numpy.random.seed(1211987)
    draws = numpy.random.randint(0,100, total)

    plt.clf()
    fig = plt.figure(figsize=(5.8,9), dpi = 200)

    for counter, i in enumerate(draws):
        c = counter + 1
        ax = fig.add_subplot(down, across, c)
        scaling = plot_community(i, ax, include_title = True, cmin = loop[graph]['min'] , max_density = loop[graph]['max'])

    fig.subplots_adjust(right=0.8)
    fig.tight_layout()

    location = 'results/community_dist_sheet_nocbar_{}.png'.format(graph)
    plt.savefig(location, alpha=True, dpi=200)
