# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import os
wd = r'/volumes/zambia'
os.chdir(wd)
from tabulate import tabulate



###################
# Gather Parts
####################

# Guide to most sig resolutions
max_values = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', 'stats/max_values')


# Get province of each thiessen
prov = pd.read_csv(r'intermediate_data/20_georeferencing_users/centroid_districts.csv')
prov = prov.rename(columns = {'PRIMARYSITEID':'primarySiteID', 'SECONDARYSITEID':'secondarySiteID', 'PROVINCE':'province'})
prov['secondarySiteID'] = prov.secondarySiteID  + 1
prov['secondarySiteID'] = prov.secondarySiteID.replace(np.nan, 0)
prov['thiessen'] = prov.secondarySiteID + prov.primarySiteID * 100000 + 9000000000

prov = prov[['thiessen','province']]

# Get Thiessen codes
users = pd.read_hdf('intermediate_data/10_edgelists_and_graphobjects/masterUsers.h5', 'thiessenCodes')[['userCode', 'thiessen_id_second']]

users_w_dist = pd.merge(users, prov, left_on='thiessen_id_second', right_on='thiessen', how='left')


# Communities


integration = pd.DataFrame(prov.province.value_counts())

for graph in ['wd7', 'wd3', 'cut3', 'cut7']:

    target_res = round(np.exp(max_values.loc[graph]['max_res']), 8)
    target_res = 'comm_{:0.8f}'.format(target_res)

    comms = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5', graph)
    comms = comms[['userCode',target_res]]

    comms_w_dist = pd.merge(comms, users_w_dist, on='userCode', how='inner')
    comms_w_dist = comms_w_dist.loc[comms_w_dist.province.notnull()]

    for p in prov.province.value_counts().index.tolist():
        c = comms_w_dist[[target_res,'province']].copy()
        c['in'] = c.province == p
        prov_pop = len(c[c['in']])
        num_total = c.groupby(target_res).size()
        num_in = c[c['in']].groupby(target_res).size()
        share_in = num_in / num_total

        weighted_avg = (share_in * (num_in / prov_pop)).sum()
        integration.loc[p,graph] = weighted_avg


integration = 1 - integration

integration = integration.drop(labels='province', axis=1)

integration['average'] = integration.mean(axis=1)
integration = integration.sort_values('average')


integration = integration[['average','cut3', 'cut7', 'wd3', 'wd7']]




headers = ['Average Score', 'All-Days, >2', 'All-Days, >6', 'Weekend-Only, >2', 'Weekend-Only, >6']
table = tabulate(integration,headers, tablefmt="latex_booktabs", floatfmt=",.3f")


with open("results/national_integration_stats.tex", "w") as outfile:
    outfile.writelines(table)
