
use $zambia/intermediate_data/35_demographics/wardELF_2010, clear
sort wardCode
merge 1:1 wardCode using $zambia/intermediate_data/35_demographics/gisCodes_wards.dta

gen density = census_pop / area_sqkm

sum density, d

* urban -- official is 39% urban./ 

gen rural_imputed = (density < 100) if density !=.

egen total_pop = sum(census_pop)
gen pop_share = census_pop / total_pop

table rural_imputed, c(sum pop_share)
preserve
	keep wardCode rural_imputed
	label var rural_imputed "Imputed Urban Ward"
	sort wardCode
	save $zambia/intermediate_data/35_demographics/urban_ward.dta, replace
	outsheet using $zambia/intermediate_data/35_demographics/urban_ward.csv, comma replace
restore
/*
* Make weighted population dist
bysort constCode: egen const_pop = sum(census_pop)

gen const_pop_share = census_pop / const_pop
bysort constCode: egen temp = sum(const_pop_share) if urban ==1
bysort constCode: egen urban_share = max(temp)
replace urban_share = 0  if urban_share ==. 
drop temp
label var urban_share "Pct Pop Urban"


**************
* Now make imputations for missing constituencies
***********


* Current coverage		
bysort distName: egen temp1 = sum(census_pop) if urban ==1		
bysort distName: egen temp2 = sum(census_pop)


duplicates drop constCode, force
keep constCode temp* urban_share


sort constCode
merge 1:1 constCode using  $zambia/intermediate_data/stata/gisCodes_consts.dta
bysort distName: egen dist_urban_pop = max(temp1)
replace dist_urban_pop = 0 if dist_urban_pop ==.
bysort distName: egen dist_pop = max(temp2)

replace dist_urban_pop = 0 if dist_urban_pop == .
replace dist_pop =0 if dist_pop == .

bysort distName: egen prob = min(_m)
sort provName distName constCode
br provName distName constCode  * if prob == 2

* Three districts: 
	* Eastern Chipata, Eastern Mambwe, Northwestern Solwezi, western Shangombo.
	* Values from 2010 Census reports. 
	gen true_urban = .
	gen true_total = .
	
	
	replace true_urban = 116627 if distName == "Chipata" & provName =="Eastern"
	replace true_total = 455783 if distName == "Chipata" & provName =="Eastern"
	
	replace true_urban = 6059 if distName == "Mambwe" & provName =="Eastern"
	replace true_total = 68918 if distName == "Mambwe" & provName =="Eastern"
	
	replace true_urban = 96725 if distName == "Solwezi" & provName =="Northwestern"
	replace true_total = 254470 if distName == "Solwezi" & provName =="Northwestern"

	replace true_urban = 2259 if distName == "Shangombo" & provName =="Western"
	replace true_total = 93303 if distName == "Shangombo" & provName =="Western"

	gen missing_urban = true_urban - dist_urban_pop 
	gen missing_total = true_total - dist_pop 
	gen missing_urban_share = missing_urban / missing_total
	replace urban_share = missing_urban_share if _m == 2
		
	br if prob  ==2
		

keep constCode urban_share



sort constCode
save $zambia/intermediate_data/35_demographics/imputed_urban_const.dta, replace
outsheet using $zambia/intermediate_data/csvs/imputed_urban_const.csv, comma replace
