clear

set more off


**************
* Consts first
**************


use $zambia/intermediate_data/35_demographics/constELF_2010, clear


sort constCode
merge 1:1 constCode using $zambia/intermediate_data/35_demographics/gisCodes_consts.dta
assert _m==3
drop _m

sort constCode
merge 1:1 constCode using $zambia/intermediate_data/35_demographics/const_2010_demographics.dta
assert _m !=1
keep if _m ==3
drop _m

sort constCode
merge 1:1 constCode using $zambia/intermediate_data/35_demographics/const_2000_demographics.dta
assert _m !=1
keep if _m ==3
drop _m

sort constCode
merge 1:1 constCode using $zambia/intermediate_data/50_elections/elections_consts.dta
assert _m !=1
keep if _m ==3
drop _m






************
* Helpful vars
************


gen ln_census_pop = log(census_pop)
label var ln_census_pop "Log Population"

	* need a dumb temp var so can use later as integer for weights
	* in picking urban cutoff
	gen pop_weight = census_pop

replace census_pop = census_pop / 1000
label var census_pop "Population ('000s)"




* ELF
label var ELF_eth "Tribe ELF"
label var ELF_ethGroup "Language ELF"

* Flags

* Lusaka  = city plus 4 bordering constituencies (2, 70, 72, 73)
gen flag_lusaka = inlist(constCode, 2,70,72,73,75,76,77,78,79,80,81)
label var flag_lusaka "Lusaka Region"

* Chingola, Kitwe, and Ndola and bordering constituencies
gen flag_copperbelt = (constCode >= 15 & constCode <= 29) | inlist(constCode, 31, 33, 34,36)
label var flag_copperbelt "Copperbelt Region"


* Areas
sum area_sqkm, d
gen pop_density = census_pop / area_sqkm
label var pop_density "Pop Density ('000s / SqKm)"
gen ln_pop_density = log(pop_density)
label var ln_pop_density "Logged Population Density"

* urban -- official is 39% urban./

sum pop_density if flag_copperbelt == 1,d

* Changes in public goods:
foreach x in protectedwater eleclight thatchroof mudfloor pca_index enrolled infant_mortality   {
	gen delta_`x' = dev_`x' - dev_`x'_2000
	gen delta_`x'_urban = dev_`x'_urban - dev_`x'_urban_2000
	gen delta_`x'_rural = dev_`x'_rural - dev_`x'_rural_2000

	}


foreach x in thatchroof mudfloor infant_mortality  {
	replace delta_`x' = - delta_`x'
	replace delta_`x'_rural = - delta_`x'_rural
	replace delta_`x'_urban = - delta_`x'_urban
}

gen delta_rural = rural - rural_2000

corr delta_protectedwater delta_eleclight delta_enrolled delta_infant_mortality
pca delta_protectedwater delta_eleclight delta_enrolled delta_infant_mortality


* Make measure of improvement for uprban rural weighted by urban rural


foreach i in protectedwater eleclight enrolled infant_mortality {
	gen wavg_`i' = delta_`i'_rural*rural + delta_`i'_urban*(1-rural)
	replace wavg_`i' = delta_`i'_rural if (rural==1 | rural_2000 == 1) & wavg_`i'==.
	replace wavg_`i' = delta_`i'_urban if (rural==0 | rural_2000 == 0) & wavg_`i'==.
}

* Two hand tweaks: one place was 99.77% rural in 2000, and had no kids, so has no enrollment value
replace wavg_enrolled = delta_enrolled_rural if delta_enrolled_urban==. & rural_2000>0.9977
replace wavg_infant_mortality = delta_infant_mortality_rural if delta_infant_mortality_urban==. & rural_2000>0.995


* Output measure correlation matrices pre-post urban-rural adjustment
label var delta_protectedwater "Water"
label var delta_eleclight "Electricity"
label var delta_enrolled "Enrollment"
label var delta_infant_mortality "Infant Mort."

label var wavg_protectedwater "Water"
label var wavg_eleclight "Electricity"
label var wavg_enrolled "Enrollment"
label var wavg_infant_mortality "Infant Mort."

corrtex delta_protectedwater delta_eleclight delta_enrolled delta_infant_mortality, ///
	file("$zambia_results/uncorrected_pgoods_corr.tex") ///
	title("Raw Inter-Public Good Measure Correlations") ///
	key("raw_pgood_corr") ///
	replace digits(2)

corrtex wavg_protectedwater wavg_eleclight wavg_enrolled wavg_infant_mortality, ///
	file("$zambia_results/corrected_pgoods_corr.tex") ///
	title("Corrected Inter-Public Good Measure Correlations") ///
	key("corrected_pgood_corr") ///
	replace digits(2)
corr wavg_*
corr delta_protectedwater delta_eleclight delta_enrolled delta_infant_mortality

foreach i in rural urban {
	pca delta_protectedwater_`i' delta_eleclight_`i' delta_enrolled_`i'
	predict dev_pca_`i'
}
capture drop dev_pca_weighted
pca wavg_*
predict dev_pca_weighted
matrix define z = e(L)
matrix z2 = z[1..4,1]
matrix rownames z2 = "Water" "Electricity" "Enrollment" "Infant Mort"
matrix colnames z2 = "Score"

outtable using $zambia_results/pca_pgood_score , ///
	mat(z2) replace center caption("Public Goods PCA Loads") clabel("pca_score") nobox f(%9.2f)


corr wavg_*
corr delta_protectedwater delta_eleclight delta_enrolled delta_infant_mortality



sort constCode
save $zambia/intermediate_data/35_demographics/consts_allbutnetwork.dta, replace
