# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import os
import sys
import re

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 100
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')

# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################


# merge statistics and merge with weights
def add_weights(district):
       
           # Get districts
    prefix = district[:-4]
    users_dist = pd.read_hdf('intermediate_data/20_georeferencing_users/weights.h5', 'user_{}_weights'.format(prefix))
    
    # Clean
    users_dist.drop('_m', axis = 1, inplace = True)    
    users_dist['weight_second'] = users_dist['weight_second'].replace(np.nan, 0)
    assert pd.isnull(users_dist['weight_first']).any()== False   
    
    # Goupby
    grouping = users_dist.groupby(district)   
    for i in ['first', 'second']:
        users_dist['total_{}'.format(i)] = grouping[['weight_{}'.format(i)]].transform(sum)
        users_dist['share_{}'.format(i)] = np.divide(
                                            users_dist['weight_{}'.format(i)], 
                                            users_dist['total_{}'.format(i)])
                                            
        t = grouping['share_{}'.format(i)].sum()
        t = t[pd.notnull(t)]
        assert ((t > 0.99) & (t < 1.01)).all()
        
        
    users_dist = users_dist[['share_second','share_first','weight_first', 'weight_second','userCode', district]]
    # Merge

    target_len = 1200 if district == 'wardCode' else 147
    assert len(users_dist[district].value_counts()) >= target_len

    return users_dist

    
def compute_weighted_averages(dist_code, data):
    data = data.copy()

    grouping = data.groupby(dist_code)
    stat_columns = [i for i in data.columns.tolist() if not re.match('(share_.*|.*Code|weight_.*)',i)] 


    columns_to_sum = list()
    for order in ['first', 'second']:
        for i in stat_columns: 
            new_col = '{}_{}'.format(i,order)
            data[new_col] = data[i] * data['share_{}'.format(order)]
            columns_to_sum.append(new_col)
            
    # Now sum
    data = data.drop(labels = stat_columns, axis=1)
    averages = grouping[columns_to_sum].sum()

    # Add pops
    averages['pop_first'] = grouping[['weight_first']].sum()
    averages['pop_second'] = grouping[['weight_second']].sum()


    averages.reset_index(inplace = True)
        
    return averages




#descriptives


wards = add_weights('wardCode')
ward_aggs = compute_weighted_averages('wardCode', wards)
ward_aggs.to_stata('intermediate_data/90_aggregated_networkstats/descriptives_wards.dta')


consts = add_weights('constCode')
const_aggs = compute_weighted_averages('constCode', consts)
const_aggs.to_stata('intermediate_data/90_aggregated_networkstats/descriptives_consts.dta')


