# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
import os
import sys
import re

#Pandas Settings
pd.options.display.notebook_repr_html = False
pd.options.display.max_rows = 100
pd.options.io.hdf.default_format = 'table'
pd.options.io.hdf.dropna_table = False
pd.set_option('mode.chained_assignment','raise')


# WD
wd = r'/Volumes/Zambia/'
os.chdir(wd)

#########################
# Body
#########################

# Import and merge with thiessen codes
def add_weights(district, communities):
       
           # Get districts
    prefix = district[:-4]
    users_dist = pd.read_hdf('intermediate_data/20_georeferencing_users/weights.h5', 'user_{}_weights'.format(prefix))
    
    # Clean
    users_dist.drop('_m', axis = 1, inplace = True)    
    users_dist['weight_second'] = users_dist['weight_second'].replace(np.nan, 0)
    assert pd.isnull(users_dist['weight_first']).any()== False   

    
    # Merge
    assert communities.index.name == 'userCode'
    users_dist = users_dist.set_index('userCode')
    len0 = len(users_dist)
    users_dist = pd.merge(users_dist, communities, how = 'left', left_index=True, right_index=True)

    assert len(users_dist) == len0

    target_len = 1200 if district == 'wardCode' else 147
    assert len(users_dist[district].value_counts()) >= target_len


    return users_dist


# Community frac      
import time

def calc_weighted_herf(district, data, graph):
    t0 = time.clock()
    stat_columns = [i for i in data.columns.tolist() if re.match('(comm_)',i)] 
    results = dict()    
    for iter,  col in enumerate(stat_columns):
        results[iter] = calc_weighted_herfs_onecolumn(district, data[['weight_second', district, col]].copy(), col)


    
    t1 = time.clock()
    print('{} minutes to do {}, dist {}'.format(((t1-t0)/60), graph, district))
    sys.stdout.flush()

    joined = pd.concat(results, axis=1, join='outer' )
    levels = joined.columns.levels
    labels = joined.columns.labels
    joined.columns = levels[1][labels[1]]

    # Drop duplicated pop columns after chekcing
    pop_columns = [i for i in joined.columns.tolist() if re.match('(pop_frac_)',i)] 

    for z in pop_columns[1:]:
        assert (abs(joined[pop_columns[0]]-joined[z]) < 0.01).all()
        joined = joined.drop(z, axis=1)

    joined = joined.rename(columns = {pop_columns[0]:'pop_from_herf'})
        
    return joined


def calc_weighted_herfs_onecolumn(district, thin_data, comm_column):

    collapsed = thin_data.groupby([district, comm_column]).sum()
    collapsed = collapsed.reset_index(level = 1)
    collapsed['district_total'] = collapsed.groupby(level = 0).transform(sum)['weight_second']
    collapsed = collapsed.query('district_total != 0').copy()
    collapsed['share'] = np.divide(collapsed['weight_second'], collapsed.district_total)

    # Check shares sum!
    temp_sum = collapsed.groupby(level = 0)['share'].sum()
    assert  ((temp_sum > 0.99) & (temp_sum < 1.01)).all()

    collapsed['share_sq'] = np.square(collapsed.share)
    frac = collapsed[['share_sq', 'weight_second']].groupby(level = 0).sum()
    frac.share_sq = 1-frac.share_sq
    
    # rename and store

    frac_col_name = re.sub('comm_', 'frac_',comm_column)
    
    frac = frac.rename(columns = {'share_sq':frac_col_name, 
                           'weight_second':'pop_{}'.format(frac_col_name)})        
    print('finished {}'.format(frac_col_name))
    sys.stdout.flush()
    return frac
    
#####
# Execute calculations
####
    
#for i in ['cut2', 'cut7', 'wd4', 'wd7']:
#    for dist in ['wardCode', 'constCode']:

herfs = dict()
 
for i in ['cut3', 'cut7', 'wd3', 'wd7']:

    # Get relevant communities
    cpm = pd.read_hdf('intermediate_data/30_communities/cpm_communities.h5',i )
    cpm = cpm.drop('vertexID', axis=1)
    cpm = cpm.set_index('userCode')    
    cpm = cpm.dropna(how='all')
    print('cpm loaded for {}'.format(i))
    sys.stdout.flush()

    for dist in ['wardCode', 'constCode']:
        cpm_w_weights = add_weights(dist, cpm)
        herfs[(dist, i)] = calc_weighted_herf(dist, cpm_w_weights, i)
        herfs[(dist, i)].to_hdf('intermediate_data/90_aggregated_networkstats/intermediate_herfs', '{}_{}'.format(dist, i))


# Load from intermediates
#herfs = dict()

#for dist in ['wardCode','constCode']:
#   for i in ['cut3', 'cut7', 'wd3', 'wd7']:
#      herfs[(dist, i)]= pd.read_hdf('intermediate_data/90_aggregated_networkstats/intermediate_herfs', '{}_{}'.format(dist, i))



# Aggregate outputs
import re

merged_herfs = dict()
for dist in ['wardCode', 'constCode']:
    # get starter index
    merged_herfs[dist] = herfs[(dist,'cut3')].copy()[[]]
    
    for i in ['cut7','cut3', 'wd3', 'wd7']:

        temp = herfs[(dist,i)].rename(columns=lambda x: re.sub('^frac','frac_{}'.format(i),x))
        temp = temp.rename(columns=lambda x: re.sub('^pop_from_herf','pop_from_herf_{}'.format(i),x))
        temp = temp.rename(columns=lambda x: re.sub('\.','_',x))

        merged_herfs[dist] = pd.merge(merged_herfs[dist], temp, left_index=True, right_index=True, how='outer')

    merged_herfs[dist].to_stata('intermediate_data/90_aggregated_networkstats/{}_herfs.dta'.format(dist[:-4]))



