set more off


* Get statistical significance
use $zambia/intermediate_data/30_communities/resolution_statistical_significance.dta, clear
replace max_res = exp(max_res)

foreach i in "cut3" "cut7" "wd3" "wd7" {
	sum max_res if graph=="`i'"
	local max_sig_res_`i' = `r(mean)'
}



*********
* Pull it all together!
*********
foreach dist in ward const {
set more off
use $zambia/intermediate_data/90_aggregated_networkstats/`dist'_herfs, clear


#delimit ;
if("`max_sig_res_cut3"=="0.000124" &
   "`max_sig_res_cut7"=="0.0068" &
   "`max_sig_res_wd3"=="0.0068" & 
   "`max_sig_res_wd7"=="0.0111"){;
	gen frac_cut3_maxsig = frac_cut3_0_00012400 ;
	gen frac_cut7_maxsig = frac_cut7_0_00680000;
	gen frac_wd3_maxsig = frac_wd3_0_00680000;
	gen frac_wd7_maxsig = frac_wd7_0_01110000;
};
else{;
	break;
	};
;

#delimit cr
	
* Add demographics

sort `dist'Code 
merge 1:1 `dist'Code using $zambia/intermediate_data/90_aggregated_networkstats/descriptives_`dist's
assert _m==3
drop _m

sort `dist'Code
merge 1:1 `dist'Code using $zambia/intermediate_data/35_demographics/`dist's_allbutnetwork.dta

if("`dist'"=="ward"){
	* One ward known not to be in ward CSO data...
	drop if `dist'Code==3213
}


assert _m~=1
keep if _m==3
drop _m


* ******
* couple vars
* ******

	* Population
	rename pop_second network_pop_2
	rename pop_first network_pop_1

	replace network_pop_2 = network_pop_2 / 1000
	label var network_pop_2 "Subscribers ('000s)"

	replace network_pop_1 = network_pop_1 / 1000
	label var network_pop_1 "Subscribers ('000s)"
	
	gen ln_net_pop = log(network_pop_2)
	label var ln_net_pop "Log Num Subscribers"

	* Coverage
	gen coverage = (network_pop_2 / census_pop) * 100
	label var coverage "Subscribers as Pct of Population"
	gen ln_coverage = log(coverage)
	label var ln_coverage "Log Subscribers as Pct of Pop"


	* Gen m
	foreach i in "cut3" "cut7" "wd3" "wd7" {
		gen max_sig_resolution_`i' = `max_sig_res_`i''
		label var max_sig_resolution_`i' "Resolution with maximal statistical significance"
	}

	
	* Religious Fragmentation
	forvalues x=1/8{
		gen temp_relig_`x' = relig_`x'^2
	}
	egen relig_frac = rowtotal(temp_relig_*)
	replace relig_frac = 1 - relig_frac
	assert relig_frac > 0 & relig_frac < 1
	corr relig_frac protestant
	assert r(rho) < 0
	label var relig_frac "Religious Fractionalization"
	
	
aorder
order `dist'Code network_pop* ln_coverage* pop_* frac_*




save $zambia/intermediate_data/100_aggregated_network_and_demographics/analysis_`dist'.dta, replace

}
